#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .compute_node import compute_node as compute_node_cls
class show_connectivity(Command):
    """
    Show machine connectivity.
    
    Parameters
    ----------
        compute_node : int
            'compute_node' child.
    
    """

    fluent_name = "show-connectivity"

    argument_names = \
        ['compute_node']

    compute_node: compute_node_cls = compute_node_cls
    """
    compute_node argument of show_connectivity.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .phase_12 import phase as phase_cls
from .name_1 import name as name_cls
from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .flowrate_frac import flowrate_frac as flowrate_frac_cls
from .elec_potential_type import elec_potential_type as elec_potential_type_cls
from .potential_value import potential_value as potential_value_cls
from .dual_potential_type import dual_potential_type as dual_potential_type_cls
from .dual_potential_value import dual_potential_value as dual_potential_value_cls
from .x_displacement_type import x_displacement_type as x_displacement_type_cls
from .x_displacement_value import x_displacement_value as x_displacement_value_cls
from .y_displacement_type import y_displacement_type as y_displacement_type_cls
from .y_displacement_value import y_displacement_value as y_displacement_value_cls
from .z_displacement_type import z_displacement_type as z_displacement_type_cls
from .z_displacement_value import z_displacement_value as z_displacement_value_cls
from .uds_bc import uds_bc as uds_bc_cls
from .uds import uds as uds_cls
from .radiation_bc import radiation_bc as radiation_bc_cls
from .coll_dtheta import coll_dtheta as coll_dtheta_cls
from .coll_dphi import coll_dphi as coll_dphi_cls
from .band_q_irrad import band_q_irrad as band_q_irrad_cls
from .band_q_irrad_diffuse import band_q_irrad_diffuse as band_q_irrad_diffuse_cls
from .parallel_collimated_beam import parallel_collimated_beam as parallel_collimated_beam_cls
from .solar_direction import solar_direction as solar_direction_cls
from .solar_irradiation import solar_irradiation as solar_irradiation_cls
from .t_b_b_spec import t_b_b_spec as t_b_b_spec_cls
from .t_b_b import t_b_b as t_b_b_cls
from .in_emiss import in_emiss as in_emiss_cls
from .dpm_bc_type import dpm_bc_type as dpm_bc_type_cls
from .dpm_bc_collision_partner import dpm_bc_collision_partner as dpm_bc_collision_partner_cls
from .reinj_inj import reinj_inj as reinj_inj_cls
from .dpm_bc_udf import dpm_bc_udf as dpm_bc_udf_cls
from .solar_fluxes import solar_fluxes as solar_fluxes_cls
from .solar_shining_factor import solar_shining_factor as solar_shining_factor_cls
from .radiating_s2s_surface import radiating_s2s_surface as radiating_s2s_surface_cls
class outflow_child(Group):
    """
    'child_object_type' of outflow.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'name', 'geom_disable', 'geom_dir_spec', 'geom_dir_x',
         'geom_dir_y', 'geom_dir_z', 'geom_levels', 'geom_bgthread',
         'flowrate_frac', 'elec_potential_type', 'potential_value',
         'dual_potential_type', 'dual_potential_value', 'x_displacement_type',
         'x_displacement_value', 'y_displacement_type',
         'y_displacement_value', 'z_displacement_type',
         'z_displacement_value', 'uds_bc', 'uds', 'radiation_bc',
         'coll_dtheta', 'coll_dphi', 'band_q_irrad', 'band_q_irrad_diffuse',
         'parallel_collimated_beam', 'solar_direction', 'solar_irradiation',
         't_b_b_spec', 't_b_b', 'in_emiss', 'dpm_bc_type',
         'dpm_bc_collision_partner', 'reinj_inj', 'dpm_bc_udf',
         'solar_fluxes', 'solar_shining_factor', 'radiating_s2s_surface']

    phase: phase_cls = phase_cls
    """
    phase child of outflow_child.
    """
    name: name_cls = name_cls
    """
    name child of outflow_child.
    """
    geom_disable: geom_disable_cls = geom_disable_cls
    """
    geom_disable child of outflow_child.
    """
    geom_dir_spec: geom_dir_spec_cls = geom_dir_spec_cls
    """
    geom_dir_spec child of outflow_child.
    """
    geom_dir_x: geom_dir_x_cls = geom_dir_x_cls
    """
    geom_dir_x child of outflow_child.
    """
    geom_dir_y: geom_dir_y_cls = geom_dir_y_cls
    """
    geom_dir_y child of outflow_child.
    """
    geom_dir_z: geom_dir_z_cls = geom_dir_z_cls
    """
    geom_dir_z child of outflow_child.
    """
    geom_levels: geom_levels_cls = geom_levels_cls
    """
    geom_levels child of outflow_child.
    """
    geom_bgthread: geom_bgthread_cls = geom_bgthread_cls
    """
    geom_bgthread child of outflow_child.
    """
    flowrate_frac: flowrate_frac_cls = flowrate_frac_cls
    """
    flowrate_frac child of outflow_child.
    """
    elec_potential_type: elec_potential_type_cls = elec_potential_type_cls
    """
    elec_potential_type child of outflow_child.
    """
    potential_value: potential_value_cls = potential_value_cls
    """
    potential_value child of outflow_child.
    """
    dual_potential_type: dual_potential_type_cls = dual_potential_type_cls
    """
    dual_potential_type child of outflow_child.
    """
    dual_potential_value: dual_potential_value_cls = dual_potential_value_cls
    """
    dual_potential_value child of outflow_child.
    """
    x_displacement_type: x_displacement_type_cls = x_displacement_type_cls
    """
    x_displacement_type child of outflow_child.
    """
    x_displacement_value: x_displacement_value_cls = x_displacement_value_cls
    """
    x_displacement_value child of outflow_child.
    """
    y_displacement_type: y_displacement_type_cls = y_displacement_type_cls
    """
    y_displacement_type child of outflow_child.
    """
    y_displacement_value: y_displacement_value_cls = y_displacement_value_cls
    """
    y_displacement_value child of outflow_child.
    """
    z_displacement_type: z_displacement_type_cls = z_displacement_type_cls
    """
    z_displacement_type child of outflow_child.
    """
    z_displacement_value: z_displacement_value_cls = z_displacement_value_cls
    """
    z_displacement_value child of outflow_child.
    """
    uds_bc: uds_bc_cls = uds_bc_cls
    """
    uds_bc child of outflow_child.
    """
    uds: uds_cls = uds_cls
    """
    uds child of outflow_child.
    """
    radiation_bc: radiation_bc_cls = radiation_bc_cls
    """
    radiation_bc child of outflow_child.
    """
    coll_dtheta: coll_dtheta_cls = coll_dtheta_cls
    """
    coll_dtheta child of outflow_child.
    """
    coll_dphi: coll_dphi_cls = coll_dphi_cls
    """
    coll_dphi child of outflow_child.
    """
    band_q_irrad: band_q_irrad_cls = band_q_irrad_cls
    """
    band_q_irrad child of outflow_child.
    """
    band_q_irrad_diffuse: band_q_irrad_diffuse_cls = band_q_irrad_diffuse_cls
    """
    band_q_irrad_diffuse child of outflow_child.
    """
    parallel_collimated_beam: parallel_collimated_beam_cls = parallel_collimated_beam_cls
    """
    parallel_collimated_beam child of outflow_child.
    """
    solar_direction: solar_direction_cls = solar_direction_cls
    """
    solar_direction child of outflow_child.
    """
    solar_irradiation: solar_irradiation_cls = solar_irradiation_cls
    """
    solar_irradiation child of outflow_child.
    """
    t_b_b_spec: t_b_b_spec_cls = t_b_b_spec_cls
    """
    t_b_b_spec child of outflow_child.
    """
    t_b_b: t_b_b_cls = t_b_b_cls
    """
    t_b_b child of outflow_child.
    """
    in_emiss: in_emiss_cls = in_emiss_cls
    """
    in_emiss child of outflow_child.
    """
    dpm_bc_type: dpm_bc_type_cls = dpm_bc_type_cls
    """
    dpm_bc_type child of outflow_child.
    """
    dpm_bc_collision_partner: dpm_bc_collision_partner_cls = dpm_bc_collision_partner_cls
    """
    dpm_bc_collision_partner child of outflow_child.
    """
    reinj_inj: reinj_inj_cls = reinj_inj_cls
    """
    reinj_inj child of outflow_child.
    """
    dpm_bc_udf: dpm_bc_udf_cls = dpm_bc_udf_cls
    """
    dpm_bc_udf child of outflow_child.
    """
    solar_fluxes: solar_fluxes_cls = solar_fluxes_cls
    """
    solar_fluxes child of outflow_child.
    """
    solar_shining_factor: solar_shining_factor_cls = solar_shining_factor_cls
    """
    solar_shining_factor child of outflow_child.
    """
    radiating_s2s_surface: radiating_s2s_surface_cls = radiating_s2s_surface_cls
    """
    radiating_s2s_surface child of outflow_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class make_steady_from_unsteady_file(Boolean):
    """
    Specify whether the unsteady sample is to be reduced into a steady-state injection file.
    """

    fluent_name = "make-steady-from-unsteady-file?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_9 import option as option_cls
from .value import value as value_cls
from .piecewise_linear import piecewise_linear as piecewise_linear_cls
from .piecewise_polynomial import piecewise_polynomial as piecewise_polynomial_cls
from .polynomial import polynomial as polynomial_cls
from .expression import expression as expression_cls
from .user_defined_function import user_defined_function as user_defined_function_cls
from .rgp_table import rgp_table as rgp_table_cls
from .real_gas_nist import real_gas_nist as real_gas_nist_cls
class thermal_conductivity(Group):
    """
    'thermal_conductivity' child.
    """

    fluent_name = "thermal-conductivity"

    child_names = \
        ['option', 'value', 'piecewise_linear', 'piecewise_polynomial',
         'polynomial', 'expression', 'user_defined_function', 'rgp_table',
         'real_gas_nist']

    option: option_cls = option_cls
    """
    option child of thermal_conductivity.
    """
    value: value_cls = value_cls
    """
    value child of thermal_conductivity.
    """
    piecewise_linear: piecewise_linear_cls = piecewise_linear_cls
    """
    piecewise_linear child of thermal_conductivity.
    """
    piecewise_polynomial: piecewise_polynomial_cls = piecewise_polynomial_cls
    """
    piecewise_polynomial child of thermal_conductivity.
    """
    polynomial: polynomial_cls = polynomial_cls
    """
    polynomial child of thermal_conductivity.
    """
    expression: expression_cls = expression_cls
    """
    expression child of thermal_conductivity.
    """
    user_defined_function: user_defined_function_cls = user_defined_function_cls
    """
    user_defined_function child of thermal_conductivity.
    """
    rgp_table: rgp_table_cls = rgp_table_cls
    """
    rgp_table child of thermal_conductivity.
    """
    real_gas_nist: real_gas_nist_cls = real_gas_nist_cls
    """
    real_gas_nist child of thermal_conductivity.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .patch_reconstructed_interface import patch_reconstructed_interface as patch_reconstructed_interface_cls
from .use_volumetric_smoothing import use_volumetric_smoothing as use_volumetric_smoothing_cls
from .smoothing_relaxation_factor import smoothing_relaxation_factor as smoothing_relaxation_factor_cls
from .execute_smoothing import execute_smoothing as execute_smoothing_cls
class vof_smooth_options(Group):
    """
    Enter the vof patch/smooth options menu.
    """

    fluent_name = "vof-smooth-options"

    child_names = \
        ['patch_reconstructed_interface', 'use_volumetric_smoothing',
         'smoothing_relaxation_factor']

    patch_reconstructed_interface: patch_reconstructed_interface_cls = patch_reconstructed_interface_cls
    """
    patch_reconstructed_interface child of vof_smooth_options.
    """
    use_volumetric_smoothing: use_volumetric_smoothing_cls = use_volumetric_smoothing_cls
    """
    use_volumetric_smoothing child of vof_smooth_options.
    """
    smoothing_relaxation_factor: smoothing_relaxation_factor_cls = smoothing_relaxation_factor_cls
    """
    smoothing_relaxation_factor child of vof_smooth_options.
    """
    command_names = \
        ['execute_smoothing']

    execute_smoothing: execute_smoothing_cls = execute_smoothing_cls
    """
    execute_smoothing command of vof_smooth_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .format_type import format_type as format_type_cls
from .precision import precision as precision_cls
class number_format(Group):
    """
    Set number-formatting options.
    """

    fluent_name = "number-format"

    child_names = \
        ['format_type', 'precision']

    format_type: format_type_cls = format_type_cls
    """
    format_type child of number_format.
    """
    precision: precision_cls = precision_cls
    """
    precision child of number_format.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .usage import usage as usage_cls
from .reset_1 import reset as reset_cls
class timer(Group):
    """
    'timer' child.
    """

    fluent_name = "timer"

    command_names = \
        ['usage', 'reset']

    usage: usage_cls = usage_cls
    """
    usage command of timer.
    """
    reset: reset_cls = reset_cls
    """
    reset command of timer.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class first_to_second_order_blending_list(RealList):
    """
    List set factor to control first order to second order blending.
    """

    fluent_name = "first-to-second-order-blending-list"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .quality_1 import quality as quality_cls
from .denoiser import denoiser as denoiser_cls
from .thread_count import thread_count as thread_count_cls
from .max_rendering_timeout import max_rendering_timeout as max_rendering_timeout_cls
class rendering(Group):
    """
    Enter the menu for rendering options.
    """

    fluent_name = "rendering"

    child_names = \
        ['quality', 'denoiser', 'thread_count', 'max_rendering_timeout']

    quality: quality_cls = quality_cls
    """
    quality child of rendering.
    """
    denoiser: denoiser_cls = denoiser_cls
    """
    denoiser child of rendering.
    """
    thread_count: thread_count_cls = thread_count_cls
    """
    thread_count child of rendering.
    """
    max_rendering_timeout: max_rendering_timeout_cls = max_rendering_timeout_cls
    """
    max_rendering_timeout child of rendering.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .number_of_partitions import number_of_partitions as number_of_partitions_cls
class combine_partition(Command):
    """
    Merge every N partitions.
    
    Parameters
    ----------
        number_of_partitions : int
            'number_of_partitions' child.
    
    """

    fluent_name = "combine-partition"

    argument_names = \
        ['number_of_partitions']

    number_of_partitions: number_of_partitions_cls = number_of_partitions_cls
    """
    number_of_partitions argument of combine_partition.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enable_3 import enable as enable_cls
from .beams import beams as beams_cls
from .statistics import statistics as statistics_cls
from .sampling_iterations import sampling_iterations as sampling_iterations_cls
from .index_of_refraction import index_of_refraction as index_of_refraction_cls
from .report import report as report_cls
from .verbosity_2 import verbosity as verbosity_cls
class optics(Group):
    """
    Enter the optics model menu.
    """

    fluent_name = "optics"

    child_names = \
        ['enable', 'beams', 'statistics', 'sampling_iterations',
         'index_of_refraction', 'report', 'verbosity']

    enable: enable_cls = enable_cls
    """
    enable child of optics.
    """
    beams: beams_cls = beams_cls
    """
    beams child of optics.
    """
    statistics: statistics_cls = statistics_cls
    """
    statistics child of optics.
    """
    sampling_iterations: sampling_iterations_cls = sampling_iterations_cls
    """
    sampling_iterations child of optics.
    """
    index_of_refraction: index_of_refraction_cls = index_of_refraction_cls
    """
    index_of_refraction child of optics.
    """
    report: report_cls = report_cls
    """
    report child of optics.
    """
    verbosity: verbosity_cls = verbosity_cls
    """
    verbosity child of optics.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class auto_time_step_size_scale_factor(Real):
    """
    Auto Time Step Size Scaling Factor.
    """

    fluent_name = "auto-time-step-size-scale-factor"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .zone_name_6 import zone_name as zone_name_cls
from .append import append as append_cls
from .text import text as text_cls
class add_suffix_or_prefix(Command):
    """
    Add suffix or prefix to zone name.
    
    Parameters
    ----------
        zone_name : typing.List[str]
            Enter zone name list.
        append : bool
            'append' child.
        text : str
            'text' child.
    
    """

    fluent_name = "add-suffix-or-prefix"

    argument_names = \
        ['zone_name', 'append', 'text']

    zone_name: zone_name_cls = zone_name_cls
    """
    zone_name argument of add_suffix_or_prefix.
    """
    append: append_cls = append_cls
    """
    append argument of add_suffix_or_prefix.
    """
    text: text_cls = text_cls
    """
    text argument of add_suffix_or_prefix.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .rom_type import rom_type as rom_type_cls
from .joule_heat_parameter import joule_heat_parameter as joule_heat_parameter_cls
from .transient_setup import transient_setup as transient_setup_cls
from .file_saving_frequency import file_saving_frequency as file_saving_frequency_cls
from .lti_rom_generation import lti_rom_generation as lti_rom_generation_cls
from .add_rom_parameter import add_rom_parameter as add_rom_parameter_cls
from .rom_data_creator import rom_data_creator as rom_data_creator_cls
from .list_rom_parameter import list_rom_parameter as list_rom_parameter_cls
from .delete_rom_parameter import delete_rom_parameter as delete_rom_parameter_cls
class rom_tool_kit(Group):
    """
    'rom_tool_kit' child.
    """

    fluent_name = "rom-tool-kit"

    child_names = \
        ['rom_type', 'joule_heat_parameter', 'transient_setup',
         'file_saving_frequency', 'lti_rom_generation']

    rom_type: rom_type_cls = rom_type_cls
    """
    rom_type child of rom_tool_kit.
    """
    joule_heat_parameter: joule_heat_parameter_cls = joule_heat_parameter_cls
    """
    joule_heat_parameter child of rom_tool_kit.
    """
    transient_setup: transient_setup_cls = transient_setup_cls
    """
    transient_setup child of rom_tool_kit.
    """
    file_saving_frequency: file_saving_frequency_cls = file_saving_frequency_cls
    """
    file_saving_frequency child of rom_tool_kit.
    """
    lti_rom_generation: lti_rom_generation_cls = lti_rom_generation_cls
    """
    lti_rom_generation child of rom_tool_kit.
    """
    command_names = \
        ['add_rom_parameter', 'rom_data_creator', 'list_rom_parameter',
         'delete_rom_parameter']

    add_rom_parameter: add_rom_parameter_cls = add_rom_parameter_cls
    """
    add_rom_parameter command of rom_tool_kit.
    """
    rom_data_creator: rom_data_creator_cls = rom_data_creator_cls
    """
    rom_data_creator command of rom_tool_kit.
    """
    list_rom_parameter: list_rom_parameter_cls = list_rom_parameter_cls
    """
    list_rom_parameter command of rom_tool_kit.
    """
    delete_rom_parameter: delete_rom_parameter_cls = delete_rom_parameter_cls
    """
    delete_rom_parameter command of rom_tool_kit.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .solve_tke import solve_tke as solve_tke_cls
from .wall_echo import wall_echo as wall_echo_cls
class reynolds_stress_options(Group):
    """
    'reynolds_stress_options' child.
    """

    fluent_name = "reynolds-stress-options"

    child_names = \
        ['solve_tke', 'wall_echo']

    solve_tke: solve_tke_cls = solve_tke_cls
    """
    solve_tke child of reynolds_stress_options.
    """
    wall_echo: wall_echo_cls = wall_echo_cls
    """
    wall_echo child of reynolds_stress_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enable_velocity_limiting import enable_velocity_limiting as enable_velocity_limiting_cls
from .set_velocity_and_vof_cutoffs import set_velocity_and_vof_cutoffs as set_velocity_and_vof_cutoffs_cls
from .set_damping_strengths import set_damping_strengths as set_damping_strengths_cls
from .set_velocity_cutoff import set_velocity_cutoff as set_velocity_cutoff_cls
from .set_damping_strength import set_damping_strength as set_damping_strength_cls
from .verbosity_5 import verbosity as verbosity_cls
class velocity_limiting_treatment(Group):
    """
    Velocity limiting related stabiity controls for VOF.
    """

    fluent_name = "velocity-limiting-treatment"

    child_names = \
        ['enable_velocity_limiting', 'set_velocity_and_vof_cutoffs',
         'set_damping_strengths', 'set_velocity_cutoff',
         'set_damping_strength', 'verbosity']

    enable_velocity_limiting: enable_velocity_limiting_cls = enable_velocity_limiting_cls
    """
    enable_velocity_limiting child of velocity_limiting_treatment.
    """
    set_velocity_and_vof_cutoffs: set_velocity_and_vof_cutoffs_cls = set_velocity_and_vof_cutoffs_cls
    """
    set_velocity_and_vof_cutoffs child of velocity_limiting_treatment.
    """
    set_damping_strengths: set_damping_strengths_cls = set_damping_strengths_cls
    """
    set_damping_strengths child of velocity_limiting_treatment.
    """
    set_velocity_cutoff: set_velocity_cutoff_cls = set_velocity_cutoff_cls
    """
    set_velocity_cutoff child of velocity_limiting_treatment.
    """
    set_damping_strength: set_damping_strength_cls = set_damping_strength_cls
    """
    set_damping_strength child of velocity_limiting_treatment.
    """
    verbosity: verbosity_cls = verbosity_cls
    """
    verbosity child of velocity_limiting_treatment.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .absolute_ode_tolerance import absolute_ode_tolerance as absolute_ode_tolerance_cls
from .relative_ode_tolerance import relative_ode_tolerance as relative_ode_tolerance_cls
class integration_options(Group):
    """
    'integration_options' child.
    """

    fluent_name = "integration-options"

    child_names = \
        ['absolute_ode_tolerance', 'relative_ode_tolerance']

    absolute_ode_tolerance: absolute_ode_tolerance_cls = absolute_ode_tolerance_cls
    """
    absolute_ode_tolerance child of integration_options.
    """
    relative_ode_tolerance: relative_ode_tolerance_cls = relative_ode_tolerance_cls
    """
    relative_ode_tolerance child of integration_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .potential import potential as potential_cls
from .joule_heating import joule_heating as joule_heating_cls
from .li_battery_enabled import li_battery_enabled as li_battery_enabled_cls
from .echemistry_enabled import echemistry_enabled as echemistry_enabled_cls
from .lithium_battery import lithium_battery as lithium_battery_cls
from .electrolysis import electrolysis as electrolysis_cls
class echemistry(Group):
    """
    Enter the potential/echemistry model settings.
    """

    fluent_name = "echemistry"

    child_names = \
        ['potential', 'joule_heating', 'li_battery_enabled',
         'echemistry_enabled', 'lithium_battery', 'electrolysis']

    potential: potential_cls = potential_cls
    """
    potential child of echemistry.
    """
    joule_heating: joule_heating_cls = joule_heating_cls
    """
    joule_heating child of echemistry.
    """
    li_battery_enabled: li_battery_enabled_cls = li_battery_enabled_cls
    """
    li_battery_enabled child of echemistry.
    """
    echemistry_enabled: echemistry_enabled_cls = echemistry_enabled_cls
    """
    echemistry_enabled child of echemistry.
    """
    lithium_battery: lithium_battery_cls = lithium_battery_cls
    """
    lithium_battery child of echemistry.
    """
    electrolysis: electrolysis_cls = electrolysis_cls
    """
    electrolysis child of echemistry.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .thread_number_control import thread_number_control as thread_number_control_cls
from .check_verbosity_1 import check_verbosity as check_verbosity_cls
from .partition_1 import partition as partition_cls
from .set_4 import set as set_cls
from .load_balance import load_balance as load_balance_cls
from .multidomain import multidomain as multidomain_cls
from .network_1 import network as network_cls
from .timer import timer as timer_cls
from .check_1 import check as check_cls
from .show_connectivity import show_connectivity as show_connectivity_cls
from .latency import latency as latency_cls
from .bandwidth import bandwidth as bandwidth_cls
class parallel(Group):
    """
    'parallel' child.
    """

    fluent_name = "parallel"

    child_names = \
        ['thread_number_control', 'check_verbosity', 'partition', 'set',
         'load_balance', 'multidomain', 'network', 'timer']

    thread_number_control: thread_number_control_cls = thread_number_control_cls
    """
    thread_number_control child of parallel.
    """
    check_verbosity: check_verbosity_cls = check_verbosity_cls
    """
    check_verbosity child of parallel.
    """
    partition: partition_cls = partition_cls
    """
    partition child of parallel.
    """
    set: set_cls = set_cls
    """
    set child of parallel.
    """
    load_balance: load_balance_cls = load_balance_cls
    """
    load_balance child of parallel.
    """
    multidomain: multidomain_cls = multidomain_cls
    """
    multidomain child of parallel.
    """
    network: network_cls = network_cls
    """
    network child of parallel.
    """
    timer: timer_cls = timer_cls
    """
    timer child of parallel.
    """
    command_names = \
        ['check', 'show_connectivity', 'latency', 'bandwidth']

    check: check_cls = check_cls
    """
    check command of parallel.
    """
    show_connectivity: show_connectivity_cls = show_connectivity_cls
    """
    show_connectivity command of parallel.
    """
    latency: latency_cls = latency_cls
    """
    latency command of parallel.
    """
    bandwidth: bandwidth_cls = bandwidth_cls
    """
    bandwidth command of parallel.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .area import area as area_cls
from .depth import depth as depth_cls
from .density_6 import density as density_cls
from .enthalpy import enthalpy as enthalpy_cls
from .length_1 import length as length_cls
from .pressure import pressure as pressure_cls
from .temperature_4 import temperature as temperature_cls
from .yplus import yplus as yplus_cls
from .velocity_3 import velocity as velocity_cls
from .viscosity_3 import viscosity as viscosity_cls
from .zone import zone as zone_cls
from .compute import compute as compute_cls
from .list_values import list_values as list_values_cls
class reference_values(Group):
    """
    'reference_values' child.
    """

    fluent_name = "reference-values"

    child_names = \
        ['area', 'depth', 'density', 'enthalpy', 'length', 'pressure',
         'temperature', 'yplus', 'velocity', 'viscosity', 'zone']

    area: area_cls = area_cls
    """
    area child of reference_values.
    """
    depth: depth_cls = depth_cls
    """
    depth child of reference_values.
    """
    density: density_cls = density_cls
    """
    density child of reference_values.
    """
    enthalpy: enthalpy_cls = enthalpy_cls
    """
    enthalpy child of reference_values.
    """
    length: length_cls = length_cls
    """
    length child of reference_values.
    """
    pressure: pressure_cls = pressure_cls
    """
    pressure child of reference_values.
    """
    temperature: temperature_cls = temperature_cls
    """
    temperature child of reference_values.
    """
    yplus: yplus_cls = yplus_cls
    """
    yplus child of reference_values.
    """
    velocity: velocity_cls = velocity_cls
    """
    velocity child of reference_values.
    """
    viscosity: viscosity_cls = viscosity_cls
    """
    viscosity child of reference_values.
    """
    zone: zone_cls = zone_cls
    """
    zone child of reference_values.
    """
    command_names = \
        ['compute', 'list_values']

    compute: compute_cls = compute_cls
    """
    compute command of reference_values.
    """
    list_values: list_values_cls = list_values_cls
    """
    list_values command of reference_values.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class operating_conditions:
    fluent_name = ...
    child_names = ...
    gravity = ...
    real_gas_state = ...
    operating_pressure = ...
    reference_pressure_location = ...
    reference_pressure_method = ...
    operating_density = ...
    operating_temperature = ...
    inlet_temperature_for_operating_density = ...
    command_names = ...

    def used_ref_pressure_location(self, ):
        """
        See the actual coordinates of reference pressure used.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .type import type as type_cls
from .layer_count import layer_count as layer_count_cls
from .boundary_list import boundary_list as boundary_list_cls
from .refine_mesh import refine_mesh as refine_mesh_cls
class multi_layer_refinement(Group):
    """
    Enter the multiple boundary layer refinement menu.
    """

    fluent_name = "multi-layer-refinement"

    child_names = \
        ['type', 'layer_count', 'boundary_list']

    type: type_cls = type_cls
    """
    type child of multi_layer_refinement.
    """
    layer_count: layer_count_cls = layer_count_cls
    """
    layer_count child of multi_layer_refinement.
    """
    boundary_list: boundary_list_cls = boundary_list_cls
    """
    boundary_list child of multi_layer_refinement.
    """
    command_names = \
        ['refine_mesh']

    refine_mesh: refine_mesh_cls = refine_mesh_cls
    """
    refine_mesh command of multi_layer_refinement.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class enable_drag_scaling(Boolean):
    """
    Enable/disable scaling of DPM drag coefficient due to inclusion of DPM volume fraction in continuous flow.
    """

    fluent_name = "enable-drag-scaling?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .display_1 import display as display_cls
from .copy_3 import copy as copy_cls
from .add_to_graphics import add_to_graphics as add_to_graphics_cls
from .clear_history import clear_history as clear_history_cls
from .xy_plot_child import xy_plot_child

class xy_plot(NamedObject[xy_plot_child], _CreatableNamedObjectMixin[xy_plot_child]):
    """
    'xy_plot' child.
    """

    fluent_name = "xy-plot"

    command_names = \
        ['display', 'copy', 'add_to_graphics', 'clear_history']

    display: display_cls = display_cls
    """
    display command of xy_plot.
    """
    copy: copy_cls = copy_cls
    """
    copy command of xy_plot.
    """
    add_to_graphics: add_to_graphics_cls = add_to_graphics_cls
    """
    add_to_graphics command of xy_plot.
    """
    clear_history: clear_history_cls = clear_history_cls
    """
    clear_history command of xy_plot.
    """
    child_object_type: xy_plot_child = xy_plot_child
    """
    child_object_type of xy_plot.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .display_4 import display as display_cls
from .history_filename import history_filename as history_filename_cls
from .report_default_variables import report_default_variables as report_default_variables_cls
from .track_single_particle_stream_1 import track_single_particle_stream as track_single_particle_stream_cls
from .arrow_scale_1 import arrow_scale as arrow_scale_cls
from .arrow_space_1 import arrow_space as arrow_space_cls
from .coarsen_factor import coarsen_factor as coarsen_factor_cls
from .line_width_1 import line_width as line_width_cls
class particle_tracks(Group):
    """
    'particle_tracks' child.
    """

    fluent_name = "particle-tracks"

    child_names = \
        ['display', 'history_filename', 'report_default_variables',
         'track_single_particle_stream', 'arrow_scale', 'arrow_space',
         'coarsen_factor', 'line_width']

    display: display_cls = display_cls
    """
    display child of particle_tracks.
    """
    history_filename: history_filename_cls = history_filename_cls
    """
    history_filename child of particle_tracks.
    """
    report_default_variables: report_default_variables_cls = report_default_variables_cls
    """
    report_default_variables child of particle_tracks.
    """
    track_single_particle_stream: track_single_particle_stream_cls = track_single_particle_stream_cls
    """
    track_single_particle_stream child of particle_tracks.
    """
    arrow_scale: arrow_scale_cls = arrow_scale_cls
    """
    arrow_scale child of particle_tracks.
    """
    arrow_space: arrow_space_cls = arrow_space_cls
    """
    arrow_space child of particle_tracks.
    """
    coarsen_factor: coarsen_factor_cls = coarsen_factor_cls
    """
    coarsen_factor child of particle_tracks.
    """
    line_width: line_width_cls = line_width_cls
    """
    line_width child of particle_tracks.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .always_use_face_centroid_with_periodics import always_use_face_centroid_with_periodics as always_use_face_centroid_with_periodics_cls
from .interpolation import interpolation as interpolation_cls
from .boundary_layer_tracking import boundary_layer_tracking as boundary_layer_tracking_cls
from .check_subtet_validity import check_subtet_validity as check_subtet_validity_cls
from .automatic_intersection_tolerance_enabled import automatic_intersection_tolerance_enabled as automatic_intersection_tolerance_enabled_cls
from .barycentric_intersection_enabled import barycentric_intersection_enabled as barycentric_intersection_enabled_cls
from .particle_relocation import particle_relocation as particle_relocation_cls
from .stuck_particle_removal_enabled import stuck_particle_removal_enabled as stuck_particle_removal_enabled_cls
from .barycentric_sampling_enabled import barycentric_sampling_enabled as barycentric_sampling_enabled_cls
from .quad_face_use_centroid_enabled import quad_face_use_centroid_enabled as quad_face_use_centroid_enabled_cls
class high_res_tracking_options(Group):
    """
    Main menu containing settings that control the High-Res Tracking scheme.
    When the High-Res Tracking option is enabled (default), the computational cells are decomposed into tetrahedrons
    (subtets) and the particles tracked through the subtets. This option provides a more robust tracking
    algorithm and improved variable interpolation. If High-Res Tracking is not enabled, particles are tracked through
    the computational cells directly. Flow variables that appear in particle equations either use cell-center values
    or a truncated Taylor series approximation for interpolation to the particle position.
    """

    fluent_name = "high-res-tracking-options"

    child_names = \
        ['always_use_face_centroid_with_periodics', 'interpolation',
         'boundary_layer_tracking', 'check_subtet_validity',
         'automatic_intersection_tolerance_enabled',
         'barycentric_intersection_enabled', 'particle_relocation',
         'stuck_particle_removal_enabled', 'barycentric_sampling_enabled',
         'quad_face_use_centroid_enabled']

    always_use_face_centroid_with_periodics: always_use_face_centroid_with_periodics_cls = always_use_face_centroid_with_periodics_cls
    """
    always_use_face_centroid_with_periodics child of high_res_tracking_options.
    """
    interpolation: interpolation_cls = interpolation_cls
    """
    interpolation child of high_res_tracking_options.
    """
    boundary_layer_tracking: boundary_layer_tracking_cls = boundary_layer_tracking_cls
    """
    boundary_layer_tracking child of high_res_tracking_options.
    """
    check_subtet_validity: check_subtet_validity_cls = check_subtet_validity_cls
    """
    check_subtet_validity child of high_res_tracking_options.
    """
    automatic_intersection_tolerance_enabled: automatic_intersection_tolerance_enabled_cls = automatic_intersection_tolerance_enabled_cls
    """
    automatic_intersection_tolerance_enabled child of high_res_tracking_options.
    """
    barycentric_intersection_enabled: barycentric_intersection_enabled_cls = barycentric_intersection_enabled_cls
    """
    barycentric_intersection_enabled child of high_res_tracking_options.
    """
    particle_relocation: particle_relocation_cls = particle_relocation_cls
    """
    particle_relocation child of high_res_tracking_options.
    """
    stuck_particle_removal_enabled: stuck_particle_removal_enabled_cls = stuck_particle_removal_enabled_cls
    """
    stuck_particle_removal_enabled child of high_res_tracking_options.
    """
    barycentric_sampling_enabled: barycentric_sampling_enabled_cls = barycentric_sampling_enabled_cls
    """
    barycentric_sampling_enabled child of high_res_tracking_options.
    """
    quad_face_use_centroid_enabled: quad_face_use_centroid_enabled_cls = quad_face_use_centroid_enabled_cls
    """
    quad_face_use_centroid_enabled child of high_res_tracking_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name import name as name_cls
from .radius_ratio import radius_ratio as radius_ratio_cls
from .chord import chord as chord_cls
from .twist import twist as twist_cls
from .airfoil_data_file import airfoil_data_file as airfoil_data_file_cls
class geometry_child(Group):
    """
    'child_object_type' of geometry.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'radius_ratio', 'chord', 'twist', 'airfoil_data_file']

    name: name_cls = name_cls
    """
    name child of geometry_child.
    """
    radius_ratio: radius_ratio_cls = radius_ratio_cls
    """
    radius_ratio child of geometry_child.
    """
    chord: chord_cls = chord_cls
    """
    chord child of geometry_child.
    """
    twist: twist_cls = twist_cls
    """
    twist child of geometry_child.
    """
    airfoil_data_file: airfoil_data_file_cls = airfoil_data_file_cls
    """
    airfoil_data_file child of geometry_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option import option as option_cls
from .constant_y0 import constant_y0 as constant_y0_cls
from .number_of_child_droplets import number_of_child_droplets as number_of_child_droplets_cls
from .constant_b1 import constant_b1 as constant_b1_cls
from .constant_b0 import constant_b0 as constant_b0_cls
from .constant_cl import constant_cl as constant_cl_cls
from .constant_ctau import constant_ctau as constant_ctau_cls
from .constant_crt import constant_crt as constant_crt_cls
from .critical_weber_number import critical_weber_number as critical_weber_number_cls
from .core_b1 import core_b1 as core_b1_cls
from .constant_xi import constant_xi as constant_xi_cls
from .target_number_in_parcel import target_number_in_parcel as target_number_in_parcel_cls
from .constant_c0 import constant_c0 as constant_c0_cls
from .column_drag_coeff import column_drag_coeff as column_drag_coeff_cls
from .ligament_factor import ligament_factor as ligament_factor_cls
from .jet_diameter import jet_diameter as jet_diameter_cls
from .constant_k1 import constant_k1 as constant_k1_cls
from .constant_k2 import constant_k2 as constant_k2_cls
from .constant_tb import constant_tb as constant_tb_cls
class droplet_breakup(Group):
    """
    'droplet_breakup' child.
    """

    fluent_name = "droplet-breakup"

    child_names = \
        ['option', 'constant_y0', 'number_of_child_droplets', 'constant_b1',
         'constant_b0', 'constant_cl', 'constant_ctau', 'constant_crt',
         'critical_weber_number', 'core_b1', 'constant_xi',
         'target_number_in_parcel', 'constant_c0', 'column_drag_coeff',
         'ligament_factor', 'jet_diameter', 'constant_k1', 'constant_k2',
         'constant_tb']

    option: option_cls = option_cls
    """
    option child of droplet_breakup.
    """
    constant_y0: constant_y0_cls = constant_y0_cls
    """
    constant_y0 child of droplet_breakup.
    """
    number_of_child_droplets: number_of_child_droplets_cls = number_of_child_droplets_cls
    """
    number_of_child_droplets child of droplet_breakup.
    """
    constant_b1: constant_b1_cls = constant_b1_cls
    """
    constant_b1 child of droplet_breakup.
    """
    constant_b0: constant_b0_cls = constant_b0_cls
    """
    constant_b0 child of droplet_breakup.
    """
    constant_cl: constant_cl_cls = constant_cl_cls
    """
    constant_cl child of droplet_breakup.
    """
    constant_ctau: constant_ctau_cls = constant_ctau_cls
    """
    constant_ctau child of droplet_breakup.
    """
    constant_crt: constant_crt_cls = constant_crt_cls
    """
    constant_crt child of droplet_breakup.
    """
    critical_weber_number: critical_weber_number_cls = critical_weber_number_cls
    """
    critical_weber_number child of droplet_breakup.
    """
    core_b1: core_b1_cls = core_b1_cls
    """
    core_b1 child of droplet_breakup.
    """
    constant_xi: constant_xi_cls = constant_xi_cls
    """
    constant_xi child of droplet_breakup.
    """
    target_number_in_parcel: target_number_in_parcel_cls = target_number_in_parcel_cls
    """
    target_number_in_parcel child of droplet_breakup.
    """
    constant_c0: constant_c0_cls = constant_c0_cls
    """
    constant_c0 child of droplet_breakup.
    """
    column_drag_coeff: column_drag_coeff_cls = column_drag_coeff_cls
    """
    column_drag_coeff child of droplet_breakup.
    """
    ligament_factor: ligament_factor_cls = ligament_factor_cls
    """
    ligament_factor child of droplet_breakup.
    """
    jet_diameter: jet_diameter_cls = jet_diameter_cls
    """
    jet_diameter child of droplet_breakup.
    """
    constant_k1: constant_k1_cls = constant_k1_cls
    """
    constant_k1 child of droplet_breakup.
    """
    constant_k2: constant_k2_cls = constant_k2_cls
    """
    constant_k2 child of droplet_breakup.
    """
    constant_tb: constant_tb_cls = constant_tb_cls
    """
    constant_tb child of droplet_breakup.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .partition_method import partition_method as partition_method_cls
from .count import count as count_cls
class method(Command):
    """
    Partition the domain.
    
    Parameters
    ----------
        partition_method : str
            'partition_method' child.
        count : int
            'count' child.
    
    """

    fluent_name = "method"

    argument_names = \
        ['partition_method', 'count']

    partition_method: partition_method_cls = partition_method_cls
    """
    partition_method argument of method.
    """
    count: count_cls = count_cls
    """
    count argument of method.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class discrete_phase:
    fluent_name = ...
    child_names = ...
    histogram = ...
    sample_trajectories = ...
    command_names = ...

    def summary(self, ):
        """
        Print discrete phase summary report of particle fates.
        """

    def extended_summary(self, write_summary_to_file: bool, file_name: str, include_in_domains_particles: bool, pick_injection: bool, injection: str):
        """
        Print extended discrete phase summary report of particle fates, with options.
        
        Parameters
        ----------
            write_summary_to_file : bool
                'write_summary_to_file' child.
            file_name : str
                'file_name' child.
            include_in_domains_particles : bool
                'include_in_domains_particles' child.
            pick_injection : bool
                'pick_injection' child.
            injection : str
                'injection' child.
        
        """

    def zone_summaries_per_injection(self, summary_state: bool, reset_dpm_summaries: bool):
        """
        Enable per-injection zone DPM summaries.
        
        Parameters
        ----------
            summary_state : bool
                'summary_state' child.
            reset_dpm_summaries : bool
                'reset_dpm_summaries' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .subspace_size import subspace_size as subspace_size_cls
from .skip_iter_count import skip_iter_count as skip_iter_count_cls
class reduced_rank_extrapolation_options(Group):
    """
    Reduced Rank Extrapolation options.
    """

    fluent_name = "reduced-rank-extrapolation-options"

    child_names = \
        ['subspace_size', 'skip_iter_count']

    subspace_size: subspace_size_cls = subspace_size_cls
    """
    subspace_size child of reduced_rank_extrapolation_options.
    """
    skip_iter_count: skip_iter_count_cls = skip_iter_count_cls
    """
    skip_iter_count child of reduced_rank_extrapolation_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .pressure_gradient_effects import pressure_gradient_effects as pressure_gradient_effects_cls
from .thermal_effects import thermal_effects as thermal_effects_cls
class enhanced_wall_treatment_options(Group):
    """
    'enhanced_wall_treatment_options' child.
    """

    fluent_name = "enhanced-wall-treatment-options"

    child_names = \
        ['pressure_gradient_effects', 'thermal_effects']

    pressure_gradient_effects: pressure_gradient_effects_cls = pressure_gradient_effects_cls
    """
    pressure_gradient_effects child of enhanced_wall_treatment_options.
    """
    thermal_effects: thermal_effects_cls = thermal_effects_cls
    """
    thermal_effects child of enhanced_wall_treatment_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .zone_name_4 import zone_name as zone_name_cls
from .shadow_zone_name import shadow_zone_name as shadow_zone_name_cls
from .rotate_periodic import rotate_periodic as rotate_periodic_cls
from .create import create as create_cls
from .auto_translation import auto_translation as auto_translation_cls
from .direction import direction as direction_cls
class make_periodic(Command):
    """
    Attempt to establish conformal periodic face zone connectivity.
    
    Parameters
    ----------
        zone_name : str
            Enter id/name of zone to convert to periodic.
        shadow_zone_name : str
            Enter id/name of zone to convert to shadow.
        rotate_periodic : bool
            'rotate_periodic' child.
        create : bool
            'create' child.
        auto_translation : bool
            'auto_translation' child.
        direction : typing.List[real]
            'direction' child.
    
    """

    fluent_name = "make-periodic"

    argument_names = \
        ['zone_name', 'shadow_zone_name', 'rotate_periodic', 'create',
         'auto_translation', 'direction']

    zone_name: zone_name_cls = zone_name_cls
    """
    zone_name argument of make_periodic.
    """
    shadow_zone_name: shadow_zone_name_cls = shadow_zone_name_cls
    """
    shadow_zone_name argument of make_periodic.
    """
    rotate_periodic: rotate_periodic_cls = rotate_periodic_cls
    """
    rotate_periodic argument of make_periodic.
    """
    create: create_cls = create_cls
    """
    create argument of make_periodic.
    """
    auto_translation: auto_translation_cls = auto_translation_cls
    """
    auto_translation argument of make_periodic.
    """
    direction: direction_cls = direction_cls
    """
    direction argument of make_periodic.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class set:
    fluent_name = ...
    child_names = ...
    adaption_method = ...
    prismatic_boundary_zones = ...
    cell_zones = ...
    dynamic_adaption_frequency = ...
    verbosity = ...
    encapsulate_children = ...
    maximum_refinement_level = ...
    minimum_edge_length = ...
    minimum_cell_quality = ...
    maximum_cell_count = ...
    additional_refinement_layers = ...
    prismatic_adaption = ...
    prismatic_split_ratio = ...
    overset_adapt_dead_cells = ...
    command_names = ...

    def dynamic_adaption(self, enable: bool):
        """
        Adapt the mesh during solution.
        
        Parameters
        ----------
            enable : bool
                'enable' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .io_mode import io_mode as io_mode_cls
from .compression_level import compression_level as compression_level_cls
from .single_precision_data import single_precision_data as single_precision_data_cls
class cffio_options(Group):
    """
    CFF I/O options.
    """

    fluent_name = "cffio-options"

    child_names = \
        ['io_mode', 'compression_level', 'single_precision_data']

    io_mode: io_mode_cls = io_mode_cls
    """
    io_mode child of cffio_options.
    """
    compression_level: compression_level_cls = compression_level_cls
    """
    compression_level child of cffio_options.
    """
    single_precision_data: single_precision_data_cls = single_precision_data_cls
    """
    single_precision_data child of cffio_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_10 import option as option_cls
from .value_1 import value as value_cls
from .piecewise_linear import piecewise_linear as piecewise_linear_cls
from .piecewise_polynomial import piecewise_polynomial as piecewise_polynomial_cls
from .polynomial import polynomial as polynomial_cls
from .user_defined_function import user_defined_function as user_defined_function_cls
class tangential_diffusivity(Group):
    """
    'tangential_diffusivity' child.
    """

    fluent_name = "tangential-diffusivity"

    child_names = \
        ['option', 'value', 'piecewise_linear', 'piecewise_polynomial',
         'polynomial', 'user_defined_function']

    option: option_cls = option_cls
    """
    option child of tangential_diffusivity.
    """
    value: value_cls = value_cls
    """
    value child of tangential_diffusivity.
    """
    piecewise_linear: piecewise_linear_cls = piecewise_linear_cls
    """
    piecewise_linear child of tangential_diffusivity.
    """
    piecewise_polynomial: piecewise_polynomial_cls = piecewise_polynomial_cls
    """
    piecewise_polynomial child of tangential_diffusivity.
    """
    polynomial: polynomial_cls = polynomial_cls
    """
    polynomial child of tangential_diffusivity.
    """
    user_defined_function: user_defined_function_cls = user_defined_function_cls
    """
    user_defined_function child of tangential_diffusivity.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .scheme_proc import scheme_proc as scheme_proc_cls
from .udf_side import udf_side as udf_side_cls
from .expression_2 import expression as expression_cls
from .list_4 import list as list_cls
class input_parameters(Group):
    """
    Enter the input-parameters menu.
    """

    fluent_name = "input-parameters"

    child_names = \
        ['scheme_proc', 'udf_side', 'expression']

    scheme_proc: scheme_proc_cls = scheme_proc_cls
    """
    scheme_proc child of input_parameters.
    """
    udf_side: udf_side_cls = udf_side_cls
    """
    udf_side child of input_parameters.
    """
    expression: expression_cls = expression_cls
    """
    expression child of input_parameters.
    """
    command_names = \
        ['list']

    list: list_cls = list_cls
    """
    list command of input_parameters.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .merge_iterations import merge_iterations as merge_iterations_cls
class merge_clusters(Command):
    """
    Merge partition clusters.
    
    Parameters
    ----------
        merge_iterations : int
            'merge_iterations' child.
    
    """

    fluent_name = "merge-clusters"

    argument_names = \
        ['merge_iterations']

    merge_iterations: merge_iterations_cls = merge_iterations_cls
    """
    merge_iterations argument of merge_clusters.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .zone_name_6 import zone_name as zone_name_cls
from .abbreviate_types import abbreviate_types as abbreviate_types_cls
from .exclude import exclude as exclude_cls
class rename_by_adjacency(Command):
    """
    Rename zone to adjacent zones.
    
    Parameters
    ----------
        zone_name : typing.List[str]
            Enter zone name list.
        abbreviate_types : bool
            'abbreviate_types' child.
        exclude : bool
            'exclude' child.
    
    """

    fluent_name = "rename-by-adjacency"

    argument_names = \
        ['zone_name', 'abbreviate_types', 'exclude']

    zone_name: zone_name_cls = zone_name_cls
    """
    zone_name argument of rename_by_adjacency.
    """
    abbreviate_types: abbreviate_types_cls = abbreviate_types_cls
    """
    abbreviate_types argument of rename_by_adjacency.
    """
    exclude: exclude_cls = exclude_cls
    """
    exclude argument of rename_by_adjacency.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .point1 import point1 as point1_cls
from .point2_or_vector import point2_or_vector as point2_or_vector_cls
from .diameter_1 import diameter as diameter_cls
class injection_hole_child(Group):
    """
    'child_object_type' of injection_hole.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['point1', 'point2_or_vector', 'diameter']

    point1: point1_cls = point1_cls
    """
    point1 child of injection_hole_child.
    """
    point2_or_vector: point2_or_vector_cls = point2_or_vector_cls
    """
    point2_or_vector child of injection_hole_child.
    """
    diameter: diameter_cls = diameter_cls
    """
    diameter child of injection_hole_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name_1 import name as name_cls
from .transparency import transparency as transparency_cls
from .colormap_position import colormap_position as colormap_position_cls
from .colormap_left import colormap_left as colormap_left_cls
from .colormap_bottom import colormap_bottom as colormap_bottom_cls
from .colormap_width import colormap_width as colormap_width_cls
from .colormap_height import colormap_height as colormap_height_cls
class graphics_objects_child(Group):
    """
    'child_object_type' of graphics_objects.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'transparency', 'colormap_position', 'colormap_left',
         'colormap_bottom', 'colormap_width', 'colormap_height']

    name: name_cls = name_cls
    """
    name child of graphics_objects_child.
    """
    transparency: transparency_cls = transparency_cls
    """
    transparency child of graphics_objects_child.
    """
    colormap_position: colormap_position_cls = colormap_position_cls
    """
    colormap_position child of graphics_objects_child.
    """
    colormap_left: colormap_left_cls = colormap_left_cls
    """
    colormap_left child of graphics_objects_child.
    """
    colormap_bottom: colormap_bottom_cls = colormap_bottom_cls
    """
    colormap_bottom child of graphics_objects_child.
    """
    colormap_width: colormap_width_cls = colormap_width_cls
    """
    colormap_width child of graphics_objects_child.
    """
    colormap_height: colormap_height_cls = colormap_height_cls
    """
    colormap_height child of graphics_objects_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class convert_hanging_nodes_during_read(Boolean):
    """
    Indicate whether meshes with hanging-nodes will be converted to polyhedra while reading.
    """

    fluent_name = "convert-hanging-nodes-during-read?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .report_name import report_name as report_name_cls
class duplicate_simulation_report(Command):
    """
    Duplicate a report and all of its settings to a new report.
    
    Parameters
    ----------
        report_name : str
            'report_name' child.
    
    """

    fluent_name = "duplicate-simulation-report"

    argument_names = \
        ['report_name']

    report_name: report_name_cls = report_name_cls
    """
    report_name argument of duplicate_simulation_report.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .zone_names_5 import zone_names as zone_names_cls
from .new_type import new_type as new_type_cls
class zone_type(Command):
    """
    Set a zone's type.
    
    Parameters
    ----------
        zone_names : typing.List[str]
            Enter zone id/name.
        new_type : str
            'new_type' child.
    
    """

    fluent_name = "zone-type"

    argument_names = \
        ['zone_names', 'new_type']

    zone_names: zone_names_cls = zone_names_cls
    """
    zone_names argument of zone_type.
    """
    new_type: new_type_cls = new_type_cls
    """
    new_type argument of zone_type.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .verbosity_10 import verbosity as verbosity_cls
from .time_step_method_1 import time_step_method as time_step_method_cls
class pseudo_time_settings(Group):
    """
    'pseudo_time_settings' child.
    """

    fluent_name = "pseudo-time-settings"

    child_names = \
        ['verbosity', 'time_step_method']

    verbosity: verbosity_cls = verbosity_cls
    """
    verbosity child of pseudo_time_settings.
    """
    time_step_method: time_step_method_cls = time_step_method_cls
    """
    time_step_method child of pseudo_time_settings.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .porous_jump_turb_wall_treatment import porous_jump_turb_wall_treatment as porous_jump_turb_wall_treatment_cls
from .dir import dir as dir_cls
from .average_dp import average_dp as average_dp_cls
from .pressure_jump import pressure_jump as pressure_jump_cls
from .limit_range import limit_range as limit_range_cls
from .v_min import v_min as v_min_cls
from .v_max import v_max as v_max_cls
from .strength import strength as strength_cls
from .profile_dp import profile_dp as profile_dp_cls
from .dp_profile import dp_profile as dp_profile_cls
from .swirl_model import swirl_model as swirl_model_cls
from .fan_vr import fan_vr as fan_vr_cls
from .fr import fr as fr_cls
from .hub import hub as hub_cls
from .axis_origin_2 import axis_origin as axis_origin_cls
from .axis_direction_2 import axis_direction as axis_direction_cls
from .profile_vt import profile_vt as profile_vt_cls
from .vt_profile import vt_profile as vt_profile_cls
from .profile_vr import profile_vr as profile_vr_cls
from .vr_profile import vr_profile as vr_profile_cls
from .swirl_factor import swirl_factor as swirl_factor_cls
from .discrete_phase_bc_type import discrete_phase_bc_type as discrete_phase_bc_type_cls
from .dem_collision_partner import dem_collision_partner as dem_collision_partner_cls
from .reinj_inj import reinj_inj as reinj_inj_cls
from .discrete_phase_bc_function import discrete_phase_bc_function as discrete_phase_bc_function_cls
from .new_fan_definition import new_fan_definition as new_fan_definition_cls
class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread',
         'porous_jump_turb_wall_treatment', 'dir', 'average_dp',
         'pressure_jump', 'limit_range', 'v_min', 'v_max', 'strength',
         'profile_dp', 'dp_profile', 'swirl_model', 'fan_vr', 'fr', 'hub',
         'axis_origin', 'axis_direction', 'profile_vt', 'vt_profile',
         'profile_vr', 'vr_profile', 'swirl_factor', 'discrete_phase_bc_type',
         'dem_collision_partner', 'reinj_inj', 'discrete_phase_bc_function',
         'new_fan_definition']

    geom_disable: geom_disable_cls = geom_disable_cls
    """
    geom_disable child of phase_child.
    """
    geom_dir_spec: geom_dir_spec_cls = geom_dir_spec_cls
    """
    geom_dir_spec child of phase_child.
    """
    geom_dir_x: geom_dir_x_cls = geom_dir_x_cls
    """
    geom_dir_x child of phase_child.
    """
    geom_dir_y: geom_dir_y_cls = geom_dir_y_cls
    """
    geom_dir_y child of phase_child.
    """
    geom_dir_z: geom_dir_z_cls = geom_dir_z_cls
    """
    geom_dir_z child of phase_child.
    """
    geom_levels: geom_levels_cls = geom_levels_cls
    """
    geom_levels child of phase_child.
    """
    geom_bgthread: geom_bgthread_cls = geom_bgthread_cls
    """
    geom_bgthread child of phase_child.
    """
    porous_jump_turb_wall_treatment: porous_jump_turb_wall_treatment_cls = porous_jump_turb_wall_treatment_cls
    """
    porous_jump_turb_wall_treatment child of phase_child.
    """
    dir: dir_cls = dir_cls
    """
    dir child of phase_child.
    """
    average_dp: average_dp_cls = average_dp_cls
    """
    average_dp child of phase_child.
    """
    pressure_jump: pressure_jump_cls = pressure_jump_cls
    """
    pressure_jump child of phase_child.
    """
    limit_range: limit_range_cls = limit_range_cls
    """
    limit_range child of phase_child.
    """
    v_min: v_min_cls = v_min_cls
    """
    v_min child of phase_child.
    """
    v_max: v_max_cls = v_max_cls
    """
    v_max child of phase_child.
    """
    strength: strength_cls = strength_cls
    """
    strength child of phase_child.
    """
    profile_dp: profile_dp_cls = profile_dp_cls
    """
    profile_dp child of phase_child.
    """
    dp_profile: dp_profile_cls = dp_profile_cls
    """
    dp_profile child of phase_child.
    """
    swirl_model: swirl_model_cls = swirl_model_cls
    """
    swirl_model child of phase_child.
    """
    fan_vr: fan_vr_cls = fan_vr_cls
    """
    fan_vr child of phase_child.
    """
    fr: fr_cls = fr_cls
    """
    fr child of phase_child.
    """
    hub: hub_cls = hub_cls
    """
    hub child of phase_child.
    """
    axis_origin: axis_origin_cls = axis_origin_cls
    """
    axis_origin child of phase_child.
    """
    axis_direction: axis_direction_cls = axis_direction_cls
    """
    axis_direction child of phase_child.
    """
    profile_vt: profile_vt_cls = profile_vt_cls
    """
    profile_vt child of phase_child.
    """
    vt_profile: vt_profile_cls = vt_profile_cls
    """
    vt_profile child of phase_child.
    """
    profile_vr: profile_vr_cls = profile_vr_cls
    """
    profile_vr child of phase_child.
    """
    vr_profile: vr_profile_cls = vr_profile_cls
    """
    vr_profile child of phase_child.
    """
    swirl_factor: swirl_factor_cls = swirl_factor_cls
    """
    swirl_factor child of phase_child.
    """
    discrete_phase_bc_type: discrete_phase_bc_type_cls = discrete_phase_bc_type_cls
    """
    discrete_phase_bc_type child of phase_child.
    """
    dem_collision_partner: dem_collision_partner_cls = dem_collision_partner_cls
    """
    dem_collision_partner child of phase_child.
    """
    reinj_inj: reinj_inj_cls = reinj_inj_cls
    """
    reinj_inj child of phase_child.
    """
    discrete_phase_bc_function: discrete_phase_bc_function_cls = discrete_phase_bc_function_cls
    """
    discrete_phase_bc_function child of phase_child.
    """
    new_fan_definition: new_fan_definition_cls = new_fan_definition_cls
    """
    new_fan_definition child of phase_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class pseudo_time_step_method_solid_zone(Boolean):
    """
    Enable/disable pseudo time step method for solid zones.
    """

    fluent_name = "pseudo-time-step-method-solid-zone?"




#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class polyhedra:
    fluent_name = ...
    child_names = ...
    options = ...
    command_names = ...

    def convert_domain(self, ):
        """
        Convert entire domain to polyhedra cells.
        """

    def convert_hanging_nodes(self, ):
        """
        Convert cells with hanging nodes and faces to polyhedra.
        """

    def convert_hanging_node_zones(self, ):
        """
        Convert selected cell zones with hanging nodes and faces to polyhedra. 
        The selected cell zones cannot be connected to other zones.
        """

    def convert_skewed_cells(self, cell_thread_list: List[str], max_cell_skewness: Union[float, str], convert_skewed_cells: bool):
        """
        'convert_skewed_cells' command.
        
        Parameters
        ----------
            cell_thread_list : typing.List[str]
                Set zones where cells should be converted.
            max_cell_skewness : real
                Set target maximum cell skewness.
            convert_skewed_cells : bool
                'convert_skewed_cells' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class poly_voc_c(RealList):
    """
    List voc-poly-c  value.
    """

    fluent_name = "poly-voc-c"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .courant_number_reduction import courant_number_reduction as courant_number_reduction_cls
from .correction_reduction import correction_reduction as correction_reduction_cls
from .correction_smoothing import correction_smoothing as correction_smoothing_cls
from .species_correction_reduction import species_correction_reduction as species_correction_reduction_cls
class relaxation_factor(Group):
    """
    'relaxation_factor' child.
    """

    fluent_name = "relaxation-factor"

    child_names = \
        ['courant_number_reduction', 'correction_reduction',
         'correction_smoothing', 'species_correction_reduction']

    courant_number_reduction: courant_number_reduction_cls = courant_number_reduction_cls
    """
    courant_number_reduction child of relaxation_factor.
    """
    correction_reduction: correction_reduction_cls = correction_reduction_cls
    """
    correction_reduction child of relaxation_factor.
    """
    correction_smoothing: correction_smoothing_cls = correction_smoothing_cls
    """
    correction_smoothing child of relaxation_factor.
    """
    species_correction_reduction: species_correction_reduction_cls = species_correction_reduction_cls
    """
    species_correction_reduction child of relaxation_factor.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .viscous_heating import viscous_heating as viscous_heating_cls
from .low_pressure_boundary_slip import low_pressure_boundary_slip as low_pressure_boundary_slip_cls
from .curvature_correction import curvature_correction as curvature_correction_cls
from .corner_flow_correction import corner_flow_correction as corner_flow_correction_cls
from .compressibility_effects import compressibility_effects as compressibility_effects_cls
from .production_kato_launder_enabled import production_kato_launder_enabled as production_kato_launder_enabled_cls
from .production_limiter import production_limiter as production_limiter_cls
from .turb_buoyancy_effects import turb_buoyancy_effects as turb_buoyancy_effects_cls
from .kw_buoyancy_effects import kw_buoyancy_effects as kw_buoyancy_effects_cls
from .enable_geko import enable_geko as enable_geko_cls
class options(Group):
    """
    'options' child.
    """

    fluent_name = "options"

    child_names = \
        ['viscous_heating', 'low_pressure_boundary_slip',
         'curvature_correction', 'corner_flow_correction',
         'compressibility_effects', 'production_kato_launder_enabled',
         'production_limiter', 'turb_buoyancy_effects', 'kw_buoyancy_effects',
         'enable_geko']

    viscous_heating: viscous_heating_cls = viscous_heating_cls
    """
    viscous_heating child of options.
    """
    low_pressure_boundary_slip: low_pressure_boundary_slip_cls = low_pressure_boundary_slip_cls
    """
    low_pressure_boundary_slip child of options.
    """
    curvature_correction: curvature_correction_cls = curvature_correction_cls
    """
    curvature_correction child of options.
    """
    corner_flow_correction: corner_flow_correction_cls = corner_flow_correction_cls
    """
    corner_flow_correction child of options.
    """
    compressibility_effects: compressibility_effects_cls = compressibility_effects_cls
    """
    compressibility_effects child of options.
    """
    production_kato_launder_enabled: production_kato_launder_enabled_cls = production_kato_launder_enabled_cls
    """
    production_kato_launder_enabled child of options.
    """
    production_limiter: production_limiter_cls = production_limiter_cls
    """
    production_limiter child of options.
    """
    turb_buoyancy_effects: turb_buoyancy_effects_cls = turb_buoyancy_effects_cls
    """
    turb_buoyancy_effects child of options.
    """
    kw_buoyancy_effects: kw_buoyancy_effects_cls = kw_buoyancy_effects_cls
    """
    kw_buoyancy_effects child of options.
    """
    enable_geko: enable_geko_cls = enable_geko_cls
    """
    enable_geko child of options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .zone1_1 import zone1 as zone1_cls
from .zone2_1 import zone2 as zone2_cls
from .pitch_change_types import pitch_change_types as pitch_change_types_cls
from .mixing_plane import mixing_plane as mixing_plane_cls
from .turbo_non_overlap import turbo_non_overlap as turbo_non_overlap_cls
class turbo_interface_child(Group):
    """
    'child_object_type' of turbo_interface.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['zone1', 'zone2', 'pitch_change_types', 'mixing_plane',
         'turbo_non_overlap']

    zone1: zone1_cls = zone1_cls
    """
    zone1 child of turbo_interface_child.
    """
    zone2: zone2_cls = zone2_cls
    """
    zone2 child of turbo_interface_child.
    """
    pitch_change_types: pitch_change_types_cls = pitch_change_types_cls
    """
    pitch_change_types child of turbo_interface_child.
    """
    mixing_plane: mixing_plane_cls = mixing_plane_cls
    """
    mixing_plane child of turbo_interface_child.
    """
    turbo_non_overlap: turbo_non_overlap_cls = turbo_non_overlap_cls
    """
    turbo_non_overlap child of turbo_interface_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .file_name_1 import file_name as file_name_cls
class write_user_setting(Command):
    """
    Write the contents of the Modified Settings Summary table to a file.
    
    Parameters
    ----------
        file_name : str
            'file_name' child.
    
    """

    fluent_name = "write-user-setting"

    argument_names = \
        ['file_name']

    file_name: file_name_cls = file_name_cls
    """
    file_name argument of write_user_setting.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class partitioning_method_for_dpm_domain(String, _HasAllowedValuesMixin):
    """
    Set the DPM domain partitioning method.
    """

    fluent_name = "partitioning-method-for-dpm-domain"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .field import field as field_cls
from .option_10 import option as option_cls
from .scaling import scaling as scaling_cls
from .derivative import derivative as derivative_cls
from .size_ratio import size_ratio as size_ratio_cls
from .create_volume_surface import create_volume_surface as create_volume_surface_cls
class field_value(Group):
    """
    'field_value' child.
    """

    fluent_name = "field-value"

    child_names = \
        ['field', 'option', 'scaling', 'derivative', 'size_ratio',
         'create_volume_surface']

    field: field_cls = field_cls
    """
    field child of field_value.
    """
    option: option_cls = option_cls
    """
    option child of field_value.
    """
    scaling: scaling_cls = scaling_cls
    """
    scaling child of field_value.
    """
    derivative: derivative_cls = derivative_cls
    """
    derivative child of field_value.
    """
    size_ratio: size_ratio_cls = size_ratio_cls
    """
    size_ratio child of field_value.
    """
    create_volume_surface: create_volume_surface_cls = create_volume_surface_cls
    """
    create_volume_surface child of field_value.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .fensapice_flow_bc_subtype import fensapice_flow_bc_subtype as fensapice_flow_bc_subtype_cls
class icing(Group):
    """
    Help not available.
    """

    fluent_name = "icing"

    child_names = \
        ['fensapice_flow_bc_subtype']

    fensapice_flow_bc_subtype: fensapice_flow_bc_subtype_cls = fensapice_flow_bc_subtype_cls
    """
    fensapice_flow_bc_subtype child of icing.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name_1 import name as name_cls
from .p0 import p0 as p0_cls
from .p1 import p1 as p1_cls
from .number_of_points import number_of_points as number_of_points_cls
class rake_surface_child(Group):
    """
    'child_object_type' of rake_surface.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'p0', 'p1', 'number_of_points']

    name: name_cls = name_cls
    """
    name child of rake_surface_child.
    """
    p0: p0_cls = p0_cls
    """
    p0 child of rake_surface_child.
    """
    p1: p1_cls = p1_cls
    """
    p1 child of rake_surface_child.
    """
    number_of_points: number_of_points_cls = number_of_points_cls
    """
    number_of_points child of rake_surface_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .allow_repair_at_boundaries import allow_repair_at_boundaries as allow_repair_at_boundaries_cls
from .include_local_polyhedra_conversion_in_repair import include_local_polyhedra_conversion_in_repair as include_local_polyhedra_conversion_in_repair_cls
from .repair_poor_elements import repair_poor_elements as repair_poor_elements_cls
from .improve_quality import improve_quality as improve_quality_cls
from .repair import repair as repair_cls
from .repair_face_handedness import repair_face_handedness as repair_face_handedness_cls
from .repair_face_node_order import repair_face_node_order as repair_face_node_order_cls
from .repair_wall_distance import repair_wall_distance as repair_wall_distance_cls
class repair_improve(Group):
    """
    Enter the repair and improve quality menu.
    """

    fluent_name = "repair-improve"

    child_names = \
        ['allow_repair_at_boundaries',
         'include_local_polyhedra_conversion_in_repair']

    allow_repair_at_boundaries: allow_repair_at_boundaries_cls = allow_repair_at_boundaries_cls
    """
    allow_repair_at_boundaries child of repair_improve.
    """
    include_local_polyhedra_conversion_in_repair: include_local_polyhedra_conversion_in_repair_cls = include_local_polyhedra_conversion_in_repair_cls
    """
    include_local_polyhedra_conversion_in_repair child of repair_improve.
    """
    command_names = \
        ['repair_poor_elements', 'improve_quality', 'repair',
         'repair_face_handedness', 'repair_face_node_order',
         'repair_wall_distance']

    repair_poor_elements: repair_poor_elements_cls = repair_poor_elements_cls
    """
    repair_poor_elements command of repair_improve.
    """
    improve_quality: improve_quality_cls = improve_quality_cls
    """
    improve_quality command of repair_improve.
    """
    repair: repair_cls = repair_cls
    """
    repair command of repair_improve.
    """
    repair_face_handedness: repair_face_handedness_cls = repair_face_handedness_cls
    """
    repair_face_handedness command of repair_improve.
    """
    repair_face_node_order: repair_face_node_order_cls = repair_face_node_order_cls
    """
    repair_face_node_order command of repair_improve.
    """
    repair_wall_distance: repair_wall_distance_cls = repair_wall_distance_cls
    """
    repair_wall_distance command of repair_improve.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .under_relaxation_factor import under_relaxation_factor as under_relaxation_factor_cls
from .explicit_relaxation_factor import explicit_relaxation_factor as explicit_relaxation_factor_cls
class expert(Group):
    """
    Enter menu for expert controls.
    """

    fluent_name = "expert"

    child_names = \
        ['under_relaxation_factor', 'explicit_relaxation_factor']

    under_relaxation_factor: under_relaxation_factor_cls = under_relaxation_factor_cls
    """
    under_relaxation_factor child of expert.
    """
    explicit_relaxation_factor: explicit_relaxation_factor_cls = explicit_relaxation_factor_cls
    """
    explicit_relaxation_factor child of expert.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name_1 import name as name_cls
from .python_name_1 import python_name_1 as python_name_1_cls
from .type_7 import type as type_cls
from .display_options import display_options as display_options_cls
class cell_registers_child(Group):
    """
    'child_object_type' of cell_registers.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'python_name_1', 'type', 'display_options']

    name: name_cls = name_cls
    """
    name child of cell_registers_child.
    """
    python_name_1: python_name_1_cls = python_name_1_cls
    """
    python_name_1 child of cell_registers_child.
    """
    type: type_cls = type_cls
    """
    type child of cell_registers_child.
    """
    display_options: display_options_cls = display_options_cls
    """
    display_options child of cell_registers_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .schnerr_evap_coeff import schnerr_evap_coeff as schnerr_evap_coeff_cls
from .schnerr_cond_coeff import schnerr_cond_coeff as schnerr_cond_coeff_cls
from .max_vapor_pressure_ratio import max_vapor_pressure_ratio as max_vapor_pressure_ratio_cls
from .min_vapor_pressure import min_vapor_pressure as min_vapor_pressure_cls
from .display_clipped_pressure import display_clipped_pressure as display_clipped_pressure_cls
from .turbulent_diffusion import turbulent_diffusion as turbulent_diffusion_cls
from .old_treatment_for_turbulent_diffusion import old_treatment_for_turbulent_diffusion as old_treatment_for_turbulent_diffusion_cls
class cavitation(Group):
    """
    Cavitation numerics options menu.
    """

    fluent_name = "cavitation"

    child_names = \
        ['schnerr_evap_coeff', 'schnerr_cond_coeff',
         'max_vapor_pressure_ratio', 'min_vapor_pressure',
         'display_clipped_pressure', 'turbulent_diffusion',
         'old_treatment_for_turbulent_diffusion']

    schnerr_evap_coeff: schnerr_evap_coeff_cls = schnerr_evap_coeff_cls
    """
    schnerr_evap_coeff child of cavitation.
    """
    schnerr_cond_coeff: schnerr_cond_coeff_cls = schnerr_cond_coeff_cls
    """
    schnerr_cond_coeff child of cavitation.
    """
    max_vapor_pressure_ratio: max_vapor_pressure_ratio_cls = max_vapor_pressure_ratio_cls
    """
    max_vapor_pressure_ratio child of cavitation.
    """
    min_vapor_pressure: min_vapor_pressure_cls = min_vapor_pressure_cls
    """
    min_vapor_pressure child of cavitation.
    """
    display_clipped_pressure: display_clipped_pressure_cls = display_clipped_pressure_cls
    """
    display_clipped_pressure child of cavitation.
    """
    turbulent_diffusion: turbulent_diffusion_cls = turbulent_diffusion_cls
    """
    turbulent_diffusion child of cavitation.
    """
    old_treatment_for_turbulent_diffusion: old_treatment_for_turbulent_diffusion_cls = old_treatment_for_turbulent_diffusion_cls
    """
    old_treatment_for_turbulent_diffusion child of cavitation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .auto_time_step_size_cal import auto_time_step_size_cal as auto_time_step_size_cal_cls
from .pseudo_time_step_size import pseudo_time_step_size as pseudo_time_step_size_cls
from .options_length_scale_calc_methods import options_length_scale_calc_methods as options_length_scale_calc_methods_cls
from .auto_time_step_size_scale_factor import auto_time_step_size_scale_factor as auto_time_step_size_scale_factor_cls
from .length_scale import length_scale as length_scale_cls
from .auto_time_size_calc_solid_zone import auto_time_size_calc_solid_zone as auto_time_size_calc_solid_zone_cls
from .auto_time_solid_scale_factor import auto_time_solid_scale_factor as auto_time_solid_scale_factor_cls
from .time_step_size_for_solid_zone import time_step_size_for_solid_zone as time_step_size_for_solid_zone_cls
class global_time_step_settings(Group):
    """
    'global_time_step_settings' child.
    """

    fluent_name = "global-time-step-settings"

    child_names = \
        ['auto_time_step_size_cal', 'pseudo_time_step_size',
         'options_length_scale_calc_methods',
         'auto_time_step_size_scale_factor', 'length_scale',
         'auto_time_size_calc_solid_zone', 'auto_time_solid_scale_factor',
         'time_step_size_for_solid_zone']

    auto_time_step_size_cal: auto_time_step_size_cal_cls = auto_time_step_size_cal_cls
    """
    auto_time_step_size_cal child of global_time_step_settings.
    """
    pseudo_time_step_size: pseudo_time_step_size_cls = pseudo_time_step_size_cls
    """
    pseudo_time_step_size child of global_time_step_settings.
    """
    options_length_scale_calc_methods: options_length_scale_calc_methods_cls = options_length_scale_calc_methods_cls
    """
    options_length_scale_calc_methods child of global_time_step_settings.
    """
    auto_time_step_size_scale_factor: auto_time_step_size_scale_factor_cls = auto_time_step_size_scale_factor_cls
    """
    auto_time_step_size_scale_factor child of global_time_step_settings.
    """
    length_scale: length_scale_cls = length_scale_cls
    """
    length_scale child of global_time_step_settings.
    """
    auto_time_size_calc_solid_zone: auto_time_size_calc_solid_zone_cls = auto_time_size_calc_solid_zone_cls
    """
    auto_time_size_calc_solid_zone child of global_time_step_settings.
    """
    auto_time_solid_scale_factor: auto_time_solid_scale_factor_cls = auto_time_solid_scale_factor_cls
    """
    auto_time_solid_scale_factor child of global_time_step_settings.
    """
    time_step_size_for_solid_zone: time_step_size_for_solid_zone_cls = time_step_size_for_solid_zone_cls
    """
    time_step_size_for_solid_zone child of global_time_step_settings.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enabled_11 import enabled as enabled_cls
from .always_use_face_centroid_with_periodics import always_use_face_centroid_with_periodics as always_use_face_centroid_with_periodics_cls
from .flow_interpolation import flow_interpolation as flow_interpolation_cls
from .boundary_layer_tracking_enabled import boundary_layer_tracking_enabled as boundary_layer_tracking_enabled_cls
from .subtet_validity_checking_enabled import subtet_validity_checking_enabled as subtet_validity_checking_enabled_cls
from .auto_intersect_tol_enabled import auto_intersect_tol_enabled as auto_intersect_tol_enabled_cls
from .barycentric_intersection_enabled import barycentric_intersection_enabled as barycentric_intersection_enabled_cls
from .particle_relocation import particle_relocation as particle_relocation_cls
from .stuck_particle_removal_enabled import stuck_particle_removal_enabled as stuck_particle_removal_enabled_cls
from .barycentric_sampling_enabled import barycentric_sampling_enabled as barycentric_sampling_enabled_cls
from .quad_face_centroid_enabled import quad_face_centroid_enabled as quad_face_centroid_enabled_cls
class high_res_tracking(Group):
    """
    Main menu containing settings that control the High-Res Tracking scheme.
    When the High-Res Tracking option is enabled (default), the computational cells are decomposed into tetrahedrons
    (subtets) and the particles tracked through the subtets. This option provides a more robust tracking
    algorithm and improved variable interpolation. If High-Res Tracking is not enabled, particles are tracked through
    the computational cells directly. Flow variables that appear in particle equations either use cell-center values
    or a truncated Taylor series approximation for interpolation to the particle position.
    """

    fluent_name = "high-res-tracking"

    child_names = \
        ['enabled', 'always_use_face_centroid_with_periodics',
         'flow_interpolation', 'boundary_layer_tracking_enabled',
         'subtet_validity_checking_enabled', 'auto_intersect_tol_enabled',
         'barycentric_intersection_enabled', 'particle_relocation',
         'stuck_particle_removal_enabled', 'barycentric_sampling_enabled',
         'quad_face_centroid_enabled']

    enabled: enabled_cls = enabled_cls
    """
    enabled child of high_res_tracking.
    """
    always_use_face_centroid_with_periodics: always_use_face_centroid_with_periodics_cls = always_use_face_centroid_with_periodics_cls
    """
    always_use_face_centroid_with_periodics child of high_res_tracking.
    """
    flow_interpolation: flow_interpolation_cls = flow_interpolation_cls
    """
    flow_interpolation child of high_res_tracking.
    """
    boundary_layer_tracking_enabled: boundary_layer_tracking_enabled_cls = boundary_layer_tracking_enabled_cls
    """
    boundary_layer_tracking_enabled child of high_res_tracking.
    """
    subtet_validity_checking_enabled: subtet_validity_checking_enabled_cls = subtet_validity_checking_enabled_cls
    """
    subtet_validity_checking_enabled child of high_res_tracking.
    """
    auto_intersect_tol_enabled: auto_intersect_tol_enabled_cls = auto_intersect_tol_enabled_cls
    """
    auto_intersect_tol_enabled child of high_res_tracking.
    """
    barycentric_intersection_enabled: barycentric_intersection_enabled_cls = barycentric_intersection_enabled_cls
    """
    barycentric_intersection_enabled child of high_res_tracking.
    """
    particle_relocation: particle_relocation_cls = particle_relocation_cls
    """
    particle_relocation child of high_res_tracking.
    """
    stuck_particle_removal_enabled: stuck_particle_removal_enabled_cls = stuck_particle_removal_enabled_cls
    """
    stuck_particle_removal_enabled child of high_res_tracking.
    """
    barycentric_sampling_enabled: barycentric_sampling_enabled_cls = barycentric_sampling_enabled_cls
    """
    barycentric_sampling_enabled child of high_res_tracking.
    """
    quad_face_centroid_enabled: quad_face_centroid_enabled_cls = quad_face_centroid_enabled_cls
    """
    quad_face_centroid_enabled child of high_res_tracking.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class dpm_sample_contour_plots:
    fluent_name = ...
    child_names = ...
    select_sample = ...
    plotting_grid_interval_size = ...
    command_names = ...

    def prepare_expressions(self, ):
        """
        'prepare_expressions' command.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class global_faces_per_surface_cluster(Integer):
    """
    Manually enter global faces per surface cluster.
    """

    fluent_name = "global-faces-per-surface-cluster"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .copy_design_points import copy_design_points as copy_design_points_cls
class duplicate(Command):
    """
    Duplicate Parametric Study.
    
    Parameters
    ----------
        copy_design_points : bool
            'copy_design_points' child.
    
    """

    fluent_name = "duplicate"

    argument_names = \
        ['copy_design_points']

    copy_design_points: copy_design_points_cls = copy_design_points_cls
    """
    copy_design_points argument of duplicate.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class tke_prandtl(String, _HasAllowedValuesMixin):
    """
    Enter TKE prandtl number function.
    """

    fluent_name = "tke-prandtl"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .chemistry_agglomeration_error_tolerance import chemistry_agglomeration_error_tolerance as chemistry_agglomeration_error_tolerance_cls
from .chemistry_agglomeration_temperature_bin import chemistry_agglomeration_temperature_bin as chemistry_agglomeration_temperature_bin_cls
class chemistry_agglomeration_options(Group):
    """
    'chemistry_agglomeration_options' child.
    """

    fluent_name = "chemistry-agglomeration-options"

    child_names = \
        ['chemistry_agglomeration_error_tolerance',
         'chemistry_agglomeration_temperature_bin']

    chemistry_agglomeration_error_tolerance: chemistry_agglomeration_error_tolerance_cls = chemistry_agglomeration_error_tolerance_cls
    """
    chemistry_agglomeration_error_tolerance child of chemistry_agglomeration_options.
    """
    chemistry_agglomeration_temperature_bin: chemistry_agglomeration_temperature_bin_cls = chemistry_agglomeration_temperature_bin_cls
    """
    chemistry_agglomeration_temperature_bin child of chemistry_agglomeration_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .proximity_tolerance import proximity_tolerance as proximity_tolerance_cls
from .set_default_name_prefix import set_default_name_prefix as set_default_name_prefix_cls
from .set_one_to_one_pairing_tolerance import set_one_to_one_pairing_tolerance as set_one_to_one_pairing_tolerance_cls
from .set_minimum_area_percentage import set_minimum_area_percentage as set_minimum_area_percentage_cls
from .pairing_between_different_cell_zones_only import pairing_between_different_cell_zones_only as pairing_between_different_cell_zones_only_cls
from .pairing_between_interface_zones_only import pairing_between_interface_zones_only as pairing_between_interface_zones_only_cls
from .keep_empty_interface import keep_empty_interface as keep_empty_interface_cls
from .naming_option import naming_option as naming_option_cls
class auto_options(Group):
    """
    Enter auto-options menu.
    """

    fluent_name = "auto-options"

    child_names = \
        ['proximity_tolerance', 'set_default_name_prefix',
         'set_one_to_one_pairing_tolerance', 'set_minimum_area_percentage',
         'pairing_between_different_cell_zones_only',
         'pairing_between_interface_zones_only', 'keep_empty_interface']

    proximity_tolerance: proximity_tolerance_cls = proximity_tolerance_cls
    """
    proximity_tolerance child of auto_options.
    """
    set_default_name_prefix: set_default_name_prefix_cls = set_default_name_prefix_cls
    """
    set_default_name_prefix child of auto_options.
    """
    set_one_to_one_pairing_tolerance: set_one_to_one_pairing_tolerance_cls = set_one_to_one_pairing_tolerance_cls
    """
    set_one_to_one_pairing_tolerance child of auto_options.
    """
    set_minimum_area_percentage: set_minimum_area_percentage_cls = set_minimum_area_percentage_cls
    """
    set_minimum_area_percentage child of auto_options.
    """
    pairing_between_different_cell_zones_only: pairing_between_different_cell_zones_only_cls = pairing_between_different_cell_zones_only_cls
    """
    pairing_between_different_cell_zones_only child of auto_options.
    """
    pairing_between_interface_zones_only: pairing_between_interface_zones_only_cls = pairing_between_interface_zones_only_cls
    """
    pairing_between_interface_zones_only child of auto_options.
    """
    keep_empty_interface: keep_empty_interface_cls = keep_empty_interface_cls
    """
    keep_empty_interface child of auto_options.
    """
    command_names = \
        ['naming_option']

    naming_option: naming_option_cls = naming_option_cls
    """
    naming_option command of auto_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .mf_1 import mf as mf_cls
from .urf import urf as urf_cls
class solution_controls(Command):
    """
    Specification of mapped frequency and under-relaxation factor for mapped interfaces.
    
    Parameters
    ----------
        mf : int
            'mf' child.
        urf : real
            'urf' child.
    
    """

    fluent_name = "solution-controls"

    argument_names = \
        ['mf', 'urf']

    mf: mf_cls = mf_cls
    """
    mf argument of solution_controls.
    """
    urf: urf_cls = urf_cls
    """
    urf argument of solution_controls.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enabled_12 import enabled as enabled_cls
from .file_name import file_name as file_name_cls
class virtual_connection(Command):
    """
    'virtual_connection' command.
    
    Parameters
    ----------
        enabled : bool
            'enabled' child.
        file_name : str
            'file_name' child.
    
    """

    fluent_name = "virtual-connection"

    argument_names = \
        ['enabled', 'file_name']

    enabled: enabled_cls = enabled_cls
    """
    enabled argument of virtual_connection.
    """
    file_name: file_name_cls = file_name_cls
    """
    file_name argument of virtual_connection.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .flow_rate import flow_rate as flow_rate_cls
from .flow_rate_2 import flow_rate_2 as flow_rate_2_cls
from .total_flow_rate import total_flow_rate as total_flow_rate_cls
from .scale_by_area import scale_by_area as scale_by_area_cls
class mass_flow_rate(Group):
    """
    'mass_flow_rate' child.
    """

    fluent_name = "mass-flow-rate"

    child_names = \
        ['flow_rate', 'flow_rate_2', 'total_flow_rate', 'scale_by_area']

    flow_rate: flow_rate_cls = flow_rate_cls
    """
    flow_rate child of mass_flow_rate.
    """
    flow_rate_2: flow_rate_2_cls = flow_rate_2_cls
    """
    flow_rate_2 child of mass_flow_rate.
    """
    total_flow_rate: total_flow_rate_cls = total_flow_rate_cls
    """
    total_flow_rate child of mass_flow_rate.
    """
    scale_by_area: scale_by_area_cls = scale_by_area_cls
    """
    scale_by_area child of mass_flow_rate.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .length import length as length_cls
from .boundary import boundary as boundary_cls
class knudsen_number_calculator(Command):
    """
    Utility to compute Kudsen number based on characteristic length and boundary information.
    
    Parameters
    ----------
        length : real
            Characteristic physics length.
        boundary : str
            'boundary' child.
    
    """

    fluent_name = "knudsen-number-calculator"

    argument_names = \
        ['length', 'boundary']

    length: length_cls = length_cls
    """
    length argument of knudsen_number_calculator.
    """
    boundary: boundary_cls = boundary_cls
    """
    boundary argument of knudsen_number_calculator.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .fixed_cycle_parameters_2 import fixed_cycle_parameters as fixed_cycle_parameters_cls
from .coarsening_parameters_2 import coarsening_parameters as coarsening_parameters_cls
from .relaxation_factor_2 import relaxation_factor as relaxation_factor_cls
from .options_8 import options as options_cls
class fas_mg_controls(Group):
    """
    Enter FAS multigrid controls menu.
    """

    fluent_name = "fas-mg-controls"

    child_names = \
        ['fixed_cycle_parameters', 'coarsening_parameters',
         'relaxation_factor', 'options']

    fixed_cycle_parameters: fixed_cycle_parameters_cls = fixed_cycle_parameters_cls
    """
    fixed_cycle_parameters child of fas_mg_controls.
    """
    coarsening_parameters: coarsening_parameters_cls = coarsening_parameters_cls
    """
    coarsening_parameters child of fas_mg_controls.
    """
    relaxation_factor: relaxation_factor_cls = relaxation_factor_cls
    """
    relaxation_factor child of fas_mg_controls.
    """
    options: options_cls = options_cls
    """
    options child of fas_mg_controls.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .composition_dependent_specific_heat import composition_dependent_specific_heat as composition_dependent_specific_heat_cls
from .composition_dependent_density import composition_dependent_density as composition_dependent_density_cls
class multiple_surface_reactions(Group):
    """
    'multiple_surface_reactions' child.
    """

    fluent_name = "multiple-surface-reactions"

    child_names = \
        ['composition_dependent_specific_heat',
         'composition_dependent_density']

    composition_dependent_specific_heat: composition_dependent_specific_heat_cls = composition_dependent_specific_heat_cls
    """
    composition_dependent_specific_heat child of multiple_surface_reactions.
    """
    composition_dependent_density: composition_dependent_density_cls = composition_dependent_density_cls
    """
    composition_dependent_density child of multiple_surface_reactions.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class sa_enhanced_wall_treatment(Boolean):
    """
    Enable/disable the enhanced wall treatment for the Spalart-Allmaras model.
    If disabled, no smooth blending between the viscous sublayer and the
    log-law formulation is employed, as was done in versions previous to Fluent14.
    """

    fluent_name = "sa-enhanced-wall-treatment?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .monitor import monitor as monitor_cls
from .normalization_factor import normalization_factor as normalization_factor_cls
from .check_convergence import check_convergence as check_convergence_cls
from .absolute_criteria import absolute_criteria as absolute_criteria_cls
from .relative_criteria import relative_criteria as relative_criteria_cls
class equations_child(Group):
    """
    'child_object_type' of equations.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['monitor', 'normalization_factor', 'check_convergence',
         'absolute_criteria', 'relative_criteria']

    monitor: monitor_cls = monitor_cls
    """
    monitor child of equations_child.
    """
    normalization_factor: normalization_factor_cls = normalization_factor_cls
    """
    normalization_factor child of equations_child.
    """
    check_convergence: check_convergence_cls = check_convergence_cls
    """
    check_convergence child of equations_child.
    """
    absolute_criteria: absolute_criteria_cls = absolute_criteria_cls
    """
    absolute_criteria child of equations_child.
    """
    relative_criteria: relative_criteria_cls = relative_criteria_cls
    """
    relative_criteria child of equations_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class vof_to_max_limit(Real):
    """
    Maximum volume fraction below which mass transfer rate is set to zero.
    """

    fluent_name = "vof-to-max-limit"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_2 import option as option_cls
from .none_1 import none as none_cls
from .scale_by_global_average import scale_by_global_average as scale_by_global_average_cls
from .scale_by_zone_average import scale_by_zone_average as scale_by_zone_average_cls
from .scale_by_global_maximum import scale_by_global_maximum as scale_by_global_maximum_cls
from .scale_by_zone_maximum import scale_by_zone_maximum as scale_by_zone_maximum_cls
class scaling(Group):
    """
    'scaling' child.
    """

    fluent_name = "scaling"

    child_names = \
        ['option', 'none', 'scale_by_global_average', 'scale_by_zone_average',
         'scale_by_global_maximum', 'scale_by_zone_maximum']

    option: option_cls = option_cls
    """
    option child of scaling.
    """
    none: none_cls = none_cls
    """
    none child of scaling.
    """
    scale_by_global_average: scale_by_global_average_cls = scale_by_global_average_cls
    """
    scale_by_global_average child of scaling.
    """
    scale_by_zone_average: scale_by_zone_average_cls = scale_by_zone_average_cls
    """
    scale_by_zone_average child of scaling.
    """
    scale_by_global_maximum: scale_by_global_maximum_cls = scale_by_global_maximum_cls
    """
    scale_by_global_maximum child of scaling.
    """
    scale_by_zone_maximum: scale_by_zone_maximum_cls = scale_by_zone_maximum_cls
    """
    scale_by_zone_maximum child of scaling.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name_1 import name as name_cls
from .field import field as field_cls
from .vector_field import vector_field as vector_field_cls
from .surfaces_list import surfaces_list as surfaces_list_cls
from .scale_3 import scale as scale_cls
from .style import style as style_cls
from .skip import skip as skip_cls
from .vector_opt import vector_opt as vector_opt_cls
from .range_option import range_option as range_option_cls
from .color_map import color_map as color_map_cls
from .draw_mesh import draw_mesh as draw_mesh_cls
from .mesh_object import mesh_object as mesh_object_cls
from .display_state_name import display_state_name as display_state_name_cls
from .physics_1 import physics as physics_cls
from .geometry_5 import geometry as geometry_cls
from .surfaces_2 import surfaces as surfaces_cls
from .display_3 import display as display_cls
from .update_min_max import update_min_max as update_min_max_cls
class vector_child(Group):
    """
    'child_object_type' of vector.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'field', 'vector_field', 'surfaces_list', 'scale', 'style',
         'skip', 'vector_opt', 'range_option', 'color_map', 'draw_mesh',
         'mesh_object', 'display_state_name', 'physics', 'geometry',
         'surfaces']

    name: name_cls = name_cls
    """
    name child of vector_child.
    """
    field: field_cls = field_cls
    """
    field child of vector_child.
    """
    vector_field: vector_field_cls = vector_field_cls
    """
    vector_field child of vector_child.
    """
    surfaces_list: surfaces_list_cls = surfaces_list_cls
    """
    surfaces_list child of vector_child.
    """
    scale: scale_cls = scale_cls
    """
    scale child of vector_child.
    """
    style: style_cls = style_cls
    """
    style child of vector_child.
    """
    skip: skip_cls = skip_cls
    """
    skip child of vector_child.
    """
    vector_opt: vector_opt_cls = vector_opt_cls
    """
    vector_opt child of vector_child.
    """
    range_option: range_option_cls = range_option_cls
    """
    range_option child of vector_child.
    """
    color_map: color_map_cls = color_map_cls
    """
    color_map child of vector_child.
    """
    draw_mesh: draw_mesh_cls = draw_mesh_cls
    """
    draw_mesh child of vector_child.
    """
    mesh_object: mesh_object_cls = mesh_object_cls
    """
    mesh_object child of vector_child.
    """
    display_state_name: display_state_name_cls = display_state_name_cls
    """
    display_state_name child of vector_child.
    """
    physics: physics_cls = physics_cls
    """
    physics child of vector_child.
    """
    geometry: geometry_cls = geometry_cls
    """
    geometry child of vector_child.
    """
    surfaces: surfaces_cls = surfaces_cls
    """
    surfaces child of vector_child.
    """
    command_names = \
        ['display', 'update_min_max']

    display: display_cls = display_cls
    """
    display command of vector_child.
    """
    update_min_max: update_min_max_cls = update_min_max_cls
    """
    update_min_max command of vector_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .style import style as style_cls
from .line_width import line_width as line_width_cls
from .arrow_space import arrow_space as arrow_space_cls
from .arrow_scale import arrow_scale as arrow_scale_cls
from .marker_size_1 import marker_size as marker_size_cls
from .sphere_size import sphere_size as sphere_size_cls
from .sphere_lod import sphere_lod as sphere_lod_cls
from .radius import radius as radius_cls
from .ribbon import ribbon as ribbon_cls
class style_attribute(Group):
    """
    'style_attribute' child.
    """

    fluent_name = "style-attribute"

    child_names = \
        ['style', 'line_width', 'arrow_space', 'arrow_scale', 'marker_size',
         'sphere_size', 'sphere_lod', 'radius', 'ribbon']

    style: style_cls = style_cls
    """
    style child of style_attribute.
    """
    line_width: line_width_cls = line_width_cls
    """
    line_width child of style_attribute.
    """
    arrow_space: arrow_space_cls = arrow_space_cls
    """
    arrow_space child of style_attribute.
    """
    arrow_scale: arrow_scale_cls = arrow_scale_cls
    """
    arrow_scale child of style_attribute.
    """
    marker_size: marker_size_cls = marker_size_cls
    """
    marker_size child of style_attribute.
    """
    sphere_size: sphere_size_cls = sphere_size_cls
    """
    sphere_size child of style_attribute.
    """
    sphere_lod: sphere_lod_cls = sphere_lod_cls
    """
    sphere_lod child of style_attribute.
    """
    radius: radius_cls = radius_cls
    """
    radius child of style_attribute.
    """
    ribbon: ribbon_cls = ribbon_cls
    """
    ribbon child of style_attribute.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .basic_info import basic_info as basic_info_cls
from .disk_origin import disk_origin as disk_origin_cls
from .disk_orientation import disk_orientation as disk_orientation_cls
from .disk_id import disk_id as disk_id_cls
from .blade_pitch_angles import blade_pitch_angles as blade_pitch_angles_cls
from .blade_flap_angles import blade_flap_angles as blade_flap_angles_cls
from .tip_loss import tip_loss as tip_loss_cls
class general(Group):
    """
    Menu to define the rotor general information.
    For more details please consult the help option of the corresponding menu or TUI command.
    """

    fluent_name = "general"

    child_names = \
        ['basic_info', 'disk_origin', 'disk_orientation', 'disk_id',
         'blade_pitch_angles', 'blade_flap_angles', 'tip_loss']

    basic_info: basic_info_cls = basic_info_cls
    """
    basic_info child of general.
    """
    disk_origin: disk_origin_cls = disk_origin_cls
    """
    disk_origin child of general.
    """
    disk_orientation: disk_orientation_cls = disk_orientation_cls
    """
    disk_orientation child of general.
    """
    disk_id: disk_id_cls = disk_id_cls
    """
    disk_id child of general.
    """
    blade_pitch_angles: blade_pitch_angles_cls = blade_pitch_angles_cls
    """
    blade_pitch_angles child of general.
    """
    blade_flap_angles: blade_flap_angles_cls = blade_flap_angles_cls
    """
    blade_flap_angles child of general.
    """
    tip_loss: tip_loss_cls = tip_loss_cls
    """
    tip_loss child of general.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .flowrate_frac import flowrate_frac as flowrate_frac_cls
from .potential_boundary_condition import potential_boundary_condition as potential_boundary_condition_cls
from .potential_boundary_value import potential_boundary_value as potential_boundary_value_cls
from .electrolyte_potential_boundary_condition import electrolyte_potential_boundary_condition as electrolyte_potential_boundary_condition_cls
from .current_density_boundary_value import current_density_boundary_value as current_density_boundary_value_cls
from .x_displacement_type import x_displacement_type as x_displacement_type_cls
from .x_displacement_value import x_displacement_value as x_displacement_value_cls
from .y_displacement_type import y_displacement_type as y_displacement_type_cls
from .y_displacement_value import y_displacement_value as y_displacement_value_cls
from .z_displacement_type import z_displacement_type as z_displacement_type_cls
from .z_displacement_value import z_displacement_value as z_displacement_value_cls
from .uds_bc import uds_bc as uds_bc_cls
from .uds import uds as uds_cls
from .radiation_bc import radiation_bc as radiation_bc_cls
from .theta_width_of_beam import theta_width_of_beam as theta_width_of_beam_cls
from .phi_width_of_beam import phi_width_of_beam as phi_width_of_beam_cls
from .direct_irradiation import direct_irradiation as direct_irradiation_cls
from .diffuse_irradiation import diffuse_irradiation as diffuse_irradiation_cls
from .parallel_collimated_beam import parallel_collimated_beam as parallel_collimated_beam_cls
from .use_beeam_direction_from_solar_load_model_settings import use_beeam_direction_from_solar_load_model_settings as use_beeam_direction_from_solar_load_model_settings_cls
from .use_irradiation_from_solar_soad_model_settings import use_irradiation_from_solar_soad_model_settings as use_irradiation_from_solar_soad_model_settings_cls
from .external_black_body_temperature_method import external_black_body_temperature_method as external_black_body_temperature_method_cls
from .black_body_temperature import black_body_temperature as black_body_temperature_cls
from .internal_emissivity import internal_emissivity as internal_emissivity_cls
from .discrete_phase_bc_type import discrete_phase_bc_type as discrete_phase_bc_type_cls
from .dem_collision_partner import dem_collision_partner as dem_collision_partner_cls
from .reinj_inj import reinj_inj as reinj_inj_cls
from .discrete_phase_bc_function import discrete_phase_bc_function as discrete_phase_bc_function_cls
from .participates_in_solar_ray_tracing import participates_in_solar_ray_tracing as participates_in_solar_ray_tracing_cls
from .solar_transmissivity_factor import solar_transmissivity_factor as solar_transmissivity_factor_cls
from .radiating_s2s_surface import radiating_s2s_surface as radiating_s2s_surface_cls
class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread', 'flowrate_frac',
         'potential_boundary_condition', 'potential_boundary_value',
         'electrolyte_potential_boundary_condition',
         'current_density_boundary_value', 'x_displacement_type',
         'x_displacement_value', 'y_displacement_type',
         'y_displacement_value', 'z_displacement_type',
         'z_displacement_value', 'uds_bc', 'uds', 'radiation_bc',
         'theta_width_of_beam', 'phi_width_of_beam', 'direct_irradiation',
         'diffuse_irradiation', 'parallel_collimated_beam',
         'use_beeam_direction_from_solar_load_model_settings',
         'use_irradiation_from_solar_soad_model_settings',
         'external_black_body_temperature_method', 'black_body_temperature',
         'internal_emissivity', 'discrete_phase_bc_type',
         'dem_collision_partner', 'reinj_inj', 'discrete_phase_bc_function',
         'participates_in_solar_ray_tracing', 'solar_transmissivity_factor',
         'radiating_s2s_surface']

    geom_disable: geom_disable_cls = geom_disable_cls
    """
    geom_disable child of phase_child.
    """
    geom_dir_spec: geom_dir_spec_cls = geom_dir_spec_cls
    """
    geom_dir_spec child of phase_child.
    """
    geom_dir_x: geom_dir_x_cls = geom_dir_x_cls
    """
    geom_dir_x child of phase_child.
    """
    geom_dir_y: geom_dir_y_cls = geom_dir_y_cls
    """
    geom_dir_y child of phase_child.
    """
    geom_dir_z: geom_dir_z_cls = geom_dir_z_cls
    """
    geom_dir_z child of phase_child.
    """
    geom_levels: geom_levels_cls = geom_levels_cls
    """
    geom_levels child of phase_child.
    """
    geom_bgthread: geom_bgthread_cls = geom_bgthread_cls
    """
    geom_bgthread child of phase_child.
    """
    flowrate_frac: flowrate_frac_cls = flowrate_frac_cls
    """
    flowrate_frac child of phase_child.
    """
    potential_boundary_condition: potential_boundary_condition_cls = potential_boundary_condition_cls
    """
    potential_boundary_condition child of phase_child.
    """
    potential_boundary_value: potential_boundary_value_cls = potential_boundary_value_cls
    """
    potential_boundary_value child of phase_child.
    """
    electrolyte_potential_boundary_condition: electrolyte_potential_boundary_condition_cls = electrolyte_potential_boundary_condition_cls
    """
    electrolyte_potential_boundary_condition child of phase_child.
    """
    current_density_boundary_value: current_density_boundary_value_cls = current_density_boundary_value_cls
    """
    current_density_boundary_value child of phase_child.
    """
    x_displacement_type: x_displacement_type_cls = x_displacement_type_cls
    """
    x_displacement_type child of phase_child.
    """
    x_displacement_value: x_displacement_value_cls = x_displacement_value_cls
    """
    x_displacement_value child of phase_child.
    """
    y_displacement_type: y_displacement_type_cls = y_displacement_type_cls
    """
    y_displacement_type child of phase_child.
    """
    y_displacement_value: y_displacement_value_cls = y_displacement_value_cls
    """
    y_displacement_value child of phase_child.
    """
    z_displacement_type: z_displacement_type_cls = z_displacement_type_cls
    """
    z_displacement_type child of phase_child.
    """
    z_displacement_value: z_displacement_value_cls = z_displacement_value_cls
    """
    z_displacement_value child of phase_child.
    """
    uds_bc: uds_bc_cls = uds_bc_cls
    """
    uds_bc child of phase_child.
    """
    uds: uds_cls = uds_cls
    """
    uds child of phase_child.
    """
    radiation_bc: radiation_bc_cls = radiation_bc_cls
    """
    radiation_bc child of phase_child.
    """
    theta_width_of_beam: theta_width_of_beam_cls = theta_width_of_beam_cls
    """
    theta_width_of_beam child of phase_child.
    """
    phi_width_of_beam: phi_width_of_beam_cls = phi_width_of_beam_cls
    """
    phi_width_of_beam child of phase_child.
    """
    direct_irradiation: direct_irradiation_cls = direct_irradiation_cls
    """
    direct_irradiation child of phase_child.
    """
    diffuse_irradiation: diffuse_irradiation_cls = diffuse_irradiation_cls
    """
    diffuse_irradiation child of phase_child.
    """
    parallel_collimated_beam: parallel_collimated_beam_cls = parallel_collimated_beam_cls
    """
    parallel_collimated_beam child of phase_child.
    """
    use_beeam_direction_from_solar_load_model_settings: use_beeam_direction_from_solar_load_model_settings_cls = use_beeam_direction_from_solar_load_model_settings_cls
    """
    use_beeam_direction_from_solar_load_model_settings child of phase_child.
    """
    use_irradiation_from_solar_soad_model_settings: use_irradiation_from_solar_soad_model_settings_cls = use_irradiation_from_solar_soad_model_settings_cls
    """
    use_irradiation_from_solar_soad_model_settings child of phase_child.
    """
    external_black_body_temperature_method: external_black_body_temperature_method_cls = external_black_body_temperature_method_cls
    """
    external_black_body_temperature_method child of phase_child.
    """
    black_body_temperature: black_body_temperature_cls = black_body_temperature_cls
    """
    black_body_temperature child of phase_child.
    """
    internal_emissivity: internal_emissivity_cls = internal_emissivity_cls
    """
    internal_emissivity child of phase_child.
    """
    discrete_phase_bc_type: discrete_phase_bc_type_cls = discrete_phase_bc_type_cls
    """
    discrete_phase_bc_type child of phase_child.
    """
    dem_collision_partner: dem_collision_partner_cls = dem_collision_partner_cls
    """
    dem_collision_partner child of phase_child.
    """
    reinj_inj: reinj_inj_cls = reinj_inj_cls
    """
    reinj_inj child of phase_child.
    """
    discrete_phase_bc_function: discrete_phase_bc_function_cls = discrete_phase_bc_function_cls
    """
    discrete_phase_bc_function child of phase_child.
    """
    participates_in_solar_ray_tracing: participates_in_solar_ray_tracing_cls = participates_in_solar_ray_tracing_cls
    """
    participates_in_solar_ray_tracing child of phase_child.
    """
    solar_transmissivity_factor: solar_transmissivity_factor_cls = solar_transmissivity_factor_cls
    """
    solar_transmissivity_factor child of phase_child.
    """
    radiating_s2s_surface: radiating_s2s_surface_cls = radiating_s2s_surface_cls
    """
    radiating_s2s_surface child of phase_child.
    """
